function s_psi = Dir_Spectrum(spread, psi, psi_mean)
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
%
% Dir_Spectrum(spread, psi)
%
% Project:	"Marine Cybernetics Simulator: MCSim"
%
% Abstract:	Calculate direction spectrum values
% 
% Inputs:	spread				- Spreading factor (exponent of cosine)
%			psi					- Direction in spectrum (within [-pi pi] around psi_mean)
%			psi_mean			- Mean direction
%
% Outputs:	s_psi				- Spectrum value
%	
% Calls:	-
%
% Author:	yvind Smogeli, Autumn 2001
%
% Revision: OS, Summer 2003: Added psi_mean, this was wrong before.
%
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 

% Spectrum coefficient
K = (2^(2*spread-1)*factorial(spread)*factorial(spread-1))/(pi*factorial(2*spread-1));

% Spectrum value
s_psi = K*cos(psi-psi_mean)^(2*spread); 