%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
%
% Control_results.m
%
% Project:	"Marine Cybernetics Simulator: MCSim"
%
% Abstract:	Present MCSim simulation data from "Saved" structure in workspace.
%			"Saved" structure can be from the last simulation or loaded from
%			a stored mat-file into workspace.
%
% Inputs:	-
%
% Outputs:	-
%	
% Calls:	-
%		
% Author:	yvind Smogeli, Summer 2003
%
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 




% Change window size for big plots
window_size = [100   100   500   800];

disp('Displaying data from "Saved" structure in Workspace')
		
figure
subplot(3,1,1)
plot(Saved.t, Saved.Eta_des(:,1), 'k-', Saved.t, Saved.Eta_meas(:,1), 'b-', Saved.t, Saved.Eta_hat(:,1), 'r-')
title('\eta_{des} (black), \eta_{meas} (blue), \eta_{hat} (red)')
ylabel('x')
subplot(3,1,2)
plot(Saved.t, Saved.Eta_des(:,2), 'k-', Saved.t, Saved.Eta_meas(:,2), 'b-', Saved.t, Saved.Eta_hat(:,2), 'r-')
ylabel('y')
subplot(3,1,3)
plot(Saved.t, (180/pi).*Saved.Eta_des(:,3), 'k-', Saved.t, (180/pi).*Saved.Eta_meas(:,6), 'b-', Saved.t, (180/pi).*Saved.Eta_hat(:,3), 'r-')
ylabel('\psi [DEG]')
xlabel('t')
set(gcf,'Position',window_size);  %Enlarge window


figure
subplot(3,1,1)
plot(Saved.t, Saved.Nu_des(:,1), 'k-', Saved.t, Saved.Nu_meas(:,1), 'b-', Saved.t, Saved.Nu_hat(:,1), 'r-')
title('\nu_{des} (black), \nu_{meas} (blue), \nu_{hat} (red)')
ylabel('x')
subplot(3,1,2)
plot(Saved.t, Saved.Nu_des(:,2), 'k-', Saved.t, Saved.Nu_meas(:,2), 'b-', Saved.t, Saved.Nu_hat(:,2), 'r-')
ylabel('y')
subplot(3,1,3)
plot(Saved.t, Saved.Nu_des(:,3), 'k-', Saved.t, Saved.Nu_meas(:,6), 'b-', Saved.t, Saved.Nu_hat(:,3), 'r-')
ylabel('\psi')
xlabel('t')
set(gcf,'Position',window_size);  %Enlarge window

Saved.Tau_d = zeros(length(Saved.t),3);
for i = 1:length(Saved.t)
    Saved.Tau_d(i,:) = (B_matrix(simout_Alpha_ref(i,1:3), Control.Allocation.Params.lx, Control.Allocation.Params.ly)*simout_T_ref(i,1:3)')';
end

figure
subplot(3,1,1)
plot(Saved.t, Saved.Tau_d(:,1), 'k-', Saved.t, Saved.Tau_c(:,1),'b-.',Saved.t, Saved.Tau_T(:,1),'r-')
title('\tau_d (black), \tau_c (blue) and actual (red) thrust force [N, Nm]')
ylabel('F1')
subplot(3,1,2)
plot(Saved.t, Saved.Tau_d(:,2), 'k-', Saved.t, Saved.Tau_c(:,2),'b-.',Saved.t, Saved.Tau_T(:,2),'r-')
ylabel('F2')
subplot(3,1,3)
plot(Saved.t, Saved.Tau_d(:,3), 'k-', Saved.t, Saved.Tau_c(:,3),'b-.',Saved.t, Saved.Tau_T(:,6),'r-')
ylabel('F6')
xlabel('t')
set(gcf,'Position',window_size);  %Enlarge window




