% Thruster plots
onethruster_plots = 1;
comparison_plots = 0;
loss_plots = 0;

plottype = 2; % 1 for symbols, 2 for different lines, 3 for colors
plotthrusters = [1 2 3 4 5]; % Vector of thruster number to plot
legplot = 1; % Plot legend or not

time = Saved.t;

% Remove transients from start and end of time series
sp = 10; % startint, sec
stp = 2; % stoppoint
ep = max(time) - stp; % endint,  sec

% Calculations

for i = plotthrusters

	Beta_cc{i} = Saved.Prop{i}.Beta_cc;
	Beta_vent{i} = Saved.Prop{i}.Beta_vent;

	warning off MATLAB:divideByZero
	Beta_ax_T{i} = Saved.Prop{i}.T_p_ax./Saved.Prop{i}.T_p_nom;
	Beta_ax_Q{i} = Saved.Prop{i}.Q_p_ax./Saved.Prop{i}.Q_p_nom;
	warning on MATLAB:divideByZero
	
	T_nom{i}	= Saved.Prop{i}.T_p_nom;
	T_axloss{i} = Saved.Prop{i}.T_p_ax;
	T_ccloss{i} = T_axloss{i}.*Saved.Prop{i}.Beta_cc;
	T_ventloss{i} = T_ccloss{i}.*Saved.Prop{i}.Beta_vent;
	
	Q_nom{i} = Saved.Prop{i}.Q_p_nom;
	Q_axloss{i} = Saved.Prop{i}.Q_p_ax;
	Q_ventloss{i} = Q_axloss{i}.*Beta_vent{i}.^Par.Thruster{1}.Q_loss;
	
	T{i} = T_ventloss{i}; % Resulting thrust
	Q{i} = Q_ventloss{i}; % Resulting torque
	
	h{i} = Saved.Prop{i}.h;
	h2{i} = Saved.Prop{i}.h2;
 
    v_ax{i} = Saved.Prop{i}.Va(:,1);
	v_tr{i} = sqrt(Saved.Prop{i}.Va(:,2).^2 + Saved.Prop{i}.Va(:,3).^2);
	
	Prop_rpm{i} = Saved.Prop{i}.RPM_p;
	Motor_rpm{i} = Prop_rpm{i}*Par.Thruster{1}.gear_ratio;
	
	Q_motor{i} = Saved.Prop{i}.Q_motor;
	P_motor{i} = Q_motor{i}.*Motor_rpm{i}/60*2*pi;

	T_des{i} = Saved.Prop{i}.T_des;
	Q_ctr{i} = Saved.Prop{i}.Q_ctr;
	
	% calculate relative submergence, special measure for tunnel thruster
	if Par.Thruster{i}.type == 3
		for  c_t = 1:length(time)
			if T_axloss{i}(c_t) > 0
				h_ventloss{i}(c_t) = h2{i}(c_t);
			else
				h_ventloss{i}(c_t) = h{i}(c_t);
			end
		end
		hR{i} = h_ventloss{i}/Par.Thruster{1}.D*2;
	else
		hR{i} = h{i}/Par.Thruster{1}.D*2;
	end 

end

if onethruster_plots == 1
	
	for p = plotthrusters

		disp(['Displaying thruster ', num2str(p)])
		
        figure('Name',['Thruster ', num2str(p), ': Thrust Actual & Desired'],'NumberTitle','off')
		mcplot(time,T{p},0,plottype)
		mcplot(time,T_des{p},1,plottype)
		title(['Thruster ',num2str(p)])
		ylabel('Thrust')
		xlabel('Time')
		legend('Actual','Desired')
		
		figure('Name',['Thruster ', num2str(p), ': Propeller Torque Plot'],'NumberTitle','off')
		subplot(3,1,1)
		mcplot(time,T{p},0,plottype)
		title(['Thruster ',num2str(p)])
		ylabel('Thrust')
		subplot(3,1,2)
		mcplot(time,Q{p},0,plottype)
		ylabel('Propeller torque')
		subplot(3,1,3)
		mcplot(time,h{p},0,plottype)
		ylabel('h')
		xlabel('Time')
		
		figure('Name',['Thruster ', num2str(p), ': Thrust Production, nominal, axloss, ccloss, ventloss'],'NumberTitle','off')
		mcplot(time,T_nom{p},1,plottype,sp,ep)
		mcplot(time,T_axloss{p},2,plottype,sp,ep)
		hold on
		mcplot(time,T_ccloss{p},3,plottype,sp,ep)
		mcplot(time,T_ventloss{p},4,plottype,sp,ep)
		hold off
		ylabel('Thrust')
		legend('nominal','axloss','ccloss','ventloss')
		xlabel('Time')
		title(['Thruster ',num2str(p)])

		figure('Name',['Thruster ', num2str(p), ': Thruster RPM, Torque and Power'],'NumberTitle','off')
		subplot(3,1,1)
		mcplot(time, Motor_rpm{p},0,plottype,sp,ep)
		ylabel('Motor RPM')
		title(['Thruster ',num2str(p)])
		subplot(3,1,2)
		mcplot(time, Q_motor{p},0,plottype,sp,ep)
		ylabel('Motor Torque')
		subplot(3,1,3)
		mcplot(time, P_motor{p},0,plottype,sp,ep)
		ylabel('Motor Power')
		xlabel('Time')
		
		figure('Name',['Thruster ', num2str(p), ': Propeller height, axial velocity and transverese velocity'],'NumberTitle','off')
		subplot(3,1,1)
		mcplot(time,h{p},0,plottype,sp,ep)
		ylabel('h')
		title(['Thruster ',num2str(p)])
		subplot(3,1,2)
		mcplot(time, v_ax{p},0,plottype,sp,ep)
		ylabel('axial velocity')
		subplot(3,1,3)
		mcplot(time, v_tr{p},0,plottype,sp,ep)
		ylabel('transverse velocity')
		xlabel('Time')

	end
		
end % onethruster_plots


if loss_plots == 1

	disp('Displaying loss plots')


	figure
	clear leg
	for m = plotthrusters
		mcplot(time, Q_axloss{m},m-1,plottype,sp,ep)
		xlabel('Time')
		ylabel('Q_p ax')
		leg{m} = ['Thruster ',num2str(m)];
	end
	legend(leg)

	figure
	clear leg
	for m = plotthrusters
		mcplot(time, T_axloss{m},m-1,plottype,sp,ep)
		xlabel('Time')
		ylabel('T_p ax')
		leg{m} = ['Thruster ',num2str(m)];
	end
	legend(leg)

	figure
	clear leg
	for m = plotthrusters
		mcplot(time, Beta_ax_Q{m},m-1,plottype,sp,ep)
		xlabel('Time')
		ylabel('\beta_{Q,ax}')
		leg{m} = ['Thruster ',num2str(m)];
	end
	legend(leg)

	figure
	clear leg
	for m = plotthrusters
		mcplot(time, Beta_ax_T{m},m-1,plottype,sp,ep)
		xlabel('Time')
		ylabel('\beta_{T,ax}')
		leg{m} = ['Thruster ',num2str(m)];
	end
	legend(leg)

	figure
	clear leg
	for m = plotthrusters
		mcplot(time, k_ax{m},m-1,plottype,sp,ep)
		xlabel('Time')
		ylabel('k_{ax}')
		leg{m} = ['Thruster ',num2str(m)];
	end
	legend(leg)

	figure
	clear leg
	for m = plotthrusters
		mcplot(time, k_vent{m},m,plottype,sp,ep)
		xlabel('Time')
		ylabel('k_{vent}')
		leg{m} = ['Thruster ',num2str(m)];
	end
	legend(leg)

	figure
	clear leg
	for m = plotthrusters
		mcplot(time, Beta_cc{m},m-1,plottype,sp,ep)
		xlabel('Time')
		ylabel('\beta_{cc}')
		leg{m} = ['Thruster ',num2str(m)];
	end
	legend(leg)
	
	figure
	clear leg
	for m = plotthrusters
		mcplot(time, Beta_vent{m},m-1,plottype,sp,ep)
		xlabel('Time')
		ylabel('\beta_{vent}')
		leg{m} = ['Thruster ',num2str(m)];
	end
	legend(leg)

	figure
	clear leg
	for m = plotthrusters
		mcplot(time, hR{m},m-1,plottype,sp,ep)
		xlabel('Time')
		ylabel('h/R')
		leg{m} = ['Thruster ',num2str(m)];
	end
	legend(leg)

	figure
	clear leg
	for m = plotthrusters
		mcplot(hR{m}, Beta_vent{m},m-1,plottype)
		xlabel('h/R')
		ylabel('\beta_{vent}')
		leg{m} = ['Thruster ',num2str(m)];
	end
	legend(leg)
	
% 	figure
% 	clear leg
% 	for m = plotthrusters
% 		if Par.Thruster{m}.type == 3
% 			mcplot(time, h_ventloss{m},m-1,plottype)
% 			xlabel('time')
% 			ylabel('h ventloss')
% 			leg{m} = ['Thruster ',num2str(m)];
% 		end
% 	end
% 	legend(leg)
	
	
end % loss plots
	

if comparison_plots == 1

	disp('Displaying comparison plots')

	count = 0;

	clear leg
	for m = plotthrusters
		count = count + 1;
		leg{count} = ['Thruster ', num2str(m)];			
	end
	
	
	figure
	for m = plotthrusters
		mcplot(time, Motor_rpm{m},m-1,plottype,sp,ep)
		xlabel('Time')
		ylabel('Motor RPM')
		title('Controller comparison')
	end
	if legplot == 1 
		legend(leg)	
	end
	
	figure
	for m = plotthrusters
		mcplot(time, Q_motor{m},m-1,plottype,sp,ep)
		ylabel('Motor Torque')
		xlabel('Time')
		title('Controller comparison')
	end
	if legplot == 1 
		legend(leg)	
	end
	
	figure
	for m = plotthrusters
		mcplot(time, P_motor{m},m-1,plottype,sp,ep)
		ylabel('Motor Power')
		xlabel('Time')
		title('Controller comparison')
	end
	if legplot == 1 
		legend(leg)	
	end
	
	figure
	for m = plotthrusters
		mcplot(time,T{m},m-1,plottype,sp,ep)
		ylabel('Propeller thrust')
		xlabel('Time')
		title('Controller comparison')
	end
	if legplot == 1 
		legend(leg)	
	end
	
	figure
	for m = plotthrusters
		mcplot(time,Q{m},m-1,plottype,sp,ep)
		ylabel('Propeller torque')
		xlabel('Time')
		title('Controller comparison')
	end
	if legplot == 1 
		legend(leg)	
	end

	figure
	for m = plotthrusters
		mcplot(time,Q_ctr{m},m-1,plottype,sp,ep)
		ylabel('Commanded torque')
		xlabel('Time')
		title('Controller comparison')
	end
	if legplot == 1 
		legend(leg)	
	end

end % comparison plots


