function dummy = mcplot(x, y, m, plottype, startint, endint)
%-------------------------------------------------------------
% mcplot(x, y, m, plottype, startint, endint)
%
% Plot-routine for MCSim
%
% x			= x-vector for plotting
% y			= y-vector for plotting
% m			= curve index (if plotting more than one curve), beginning with 0
% plottype	= 1: black and white with symbols
% 			= 2: black and white with different lines
% 			= 3: colors
% startint	= interval removed from start of x series
% endint	= interval removed from end of x series
%
% Author: Oyvind Notland Smogeli
%-------------------------------------------------------------

if length(x) ~= length(y)

    disp('Vectors must be of same length for plotting!')
    return
    
else

	% Needed for automatic scaling of axis
	axis auto
    
    % Number of markers
    nmarks = 40;
    
    % Number of points in time series
    npoints = length(x);
    
    % Shorten time series, to remove transients
    if ~exist('startint')
        startint = 0;
    end
    if ~exist('endint')
        endint = 0;
    end
    	
    sp = min(find(x >= min(x) + startint));
    ep = max(find(x >= (max(x) - endint)));
  
	if sp >= ep
	
		disp('Warning: Start and end interval overlap in mcplot, whole series plotted')
		sp = min(x);
		ep = max(x);
		
	end

    x = x(sp:ep);
    y = y(sp:ep);
    
    % Modify after shortening
    npoints = length(x);
    
    
    if plottype == 1
        
        interval = max(x)/nmarks;
        
        for k = 1:nmarks
            
            selvec(k) = min(find(x>=interval*k));
            
        end
        
        xm = x(selvec);
        ym = y(selvec);
        
        
        % Plotstyles
        if ~exist('m')
            m = 0;
        end
        
        switch m
            case 1
                plotstyle = 'k*';
            case 2
                plotstyle = 'ko';
            case 3
                plotstyle = 'ks';
            case 4
                plotstyle = 'kx';
            case 5
                plotstyle = 'kd';
            otherwise
                plotstyle = 'k-';
        end
        
        plot(x,y,'k-')
        hold on
        if m ~= 0
            plot(xm,ym,plotstyle)
        end
        
    elseif plottype == 2
        
        if ~exist('m')
            m = 0;
        end
        
        switch m
            
            case 0
                plot(x,y,'k-')
                
            case 1
                plot(x,y,'k:','linewidth',2)
                
            case 2
                plot(x,y,'k-.','linewidth',1.4)
                
            case 4
                plot(x,y,'k--','linewidth',1.3)
                
            case 5
                plot(x,y,'k-','linewidth',1.3)
				
			otherwise
                plot(x,y,'k-','linewidth',1.5)
                
        end
        
        hold on
        
    elseif plottype == 3
        
        if ~exist('m')
            m = 0;
        end
        
        switch m
            
            case 0
                plot(x,y,'b-')
                
            case 1
                plot(x,y,'r:','linewidth',1.5)
                
            case 2
                plot(x,y,'k-.','linewidth',1.4)
                
            case 3
                plot(x,y,'g--','linewidth',1.3)
                
            case 4
                plot(x,y,'y-')
				
            case 5
                plot(x,y,'m--','linewidth',1.3)
				
			case 6
                plot(x,y,'k:','linewidth',1.5)
				
			otherwise
	           	plot(x,y,'k-','linewidth',1)
                
        end
        
        hold on
        
    else
        
        disp('Invalid plottype in mcplot')
        
    end
    
	% Fit window
	ax = axis;
	axis([min(x), max(x), ax(3:4)]);
	
end
    




    
