%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
% Thruster_data.m 
%
% Project:	"Marine Cybernetics Simulator: MCSim"
%
% Abstract:	Thruster data. Thruster position and orientation to be defined in "Load_thrusters.m"
% 
% Inputs:	- 
%
% Outputs:	-
%
% Calls:	-
%						
% Author:	Oyvind Smogeli, Summer 2003
%
% Revision:	-
%
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 


%************************************************************************************************************************************************
% Thruster description 1

Thrusters{1}.descr 			= 'Ka 4-70 propeller in 19A duct, P/D=1.0, EAR=0.7, 4 quadrant data';
Thrusters{1}.type			= 1;			% Thruster data defined with van Lammeren 4 quadrant data

% Main data
Thrusters{1}.Z				= 4;			% Number of blades
Thrusters{1}.D				= 4;			% Diameter
Thrusters{1}.EAR			= 0.7;			% EAR = A_E/A_0, blade area ratio
Thrusters{1}.PD				= 1.0;			% Pitch/diameter ratio
Thrusters{1}.RPM_p_max		= 150;			% Propeller max RPM
Thrusters{1}.J_p			= 5000;			% Rotational inertia of propeller, shaft and gears, seen from propeller

% Position and orientation
Thrusters{1}.r_p			= [-37.8 -5 4]';% thruster position(x,y,z). This is to be redefined when loading the thrusters
Thrusters{1}.alpha			= 0;			% thruster direction [rad], zero for thrust ahead. If rotateable, this is the inital value
Thrusters{1}.fixed_dir		= 0;			% 1 for fixed direction, 0 for rotateable thruster
Thrusters{1}.control_weight	= 1;			% Weight for thrust allocation routine, [0,1]

% Propeller motor
Thrusters{1}.RPM_m_max		= 880;			% motor RPM max speed
Thrusters{1}.P_max			= 7E6;			% Max motor power [W]
Thrusters{1}.Q_max			= 2E5;			% Max motor torque [Nm]
Thrusters{1}.T_m 			= 0.1;			% motor time constant for 1st order model

% Azimuth motor, only for rotating thrusters. Leave dummy values for non-rotateable thrusters
Thrusters{1}.T_dir			= 1;			% rotateable thruster time constant for 1st order model
Thrusters{1}.rate_dir_max	= 20*pi/180;	% rotateable thruster max rotation rate [rad/s]

% Pitch motor, only for CP thrusters. 
Thrusters{1}.T_pitch		= 0.3;			% Time constant for pitch 1st order dynamics 
Thrusters{1}.rate_PD_max	= 4/5;			% Pitch rate saturation [PD/sec] 
Thrusters{1}.PD_lim			= [-2 2];		% Validity range for PD, specific for this propeller.

% Calculate motor rate and gear ratio
Thrusters{1}.gear_ratio		= Thrusters{1}.RPM_m_max/Thrusters{1}.RPM_p_max; % Gear ratio
Thrusters{1}.J_m 			= Thrusters{1}.J_p/(Thrusters{1}.gear_ratio^2); % Rotational inertia seen from motor

Thrusters{1}.RPM_m_T		= 5;			% motor RPM max rate: 5 seconds from 0 to max
Thrusters{1}.RPM_m_rate		= Thrusters{1}.RPM_m_max/Thrusters{1}.RPM_m_T; % Max motor rate     

% Hydrodynamic data
Thrusters{1}.w				= [0.2 0 0];	% wake factor
Thrusters{1}.t				= 0.2;			% thrust deduction
Thrusters{1}.Kcc			= 1.125; 		% Cross-coupling drag coefficient
Thrusters{1}.Q_loss			= 0.65;			% Torque loss factor

% Data for hydrodynamic mass-damper model
Thrusters{1}.gamma			= 1;						% Added mass parameter
Thrusters{1}.L				= Thrusters{1}.D;		% Characteristic length, equal to duct length for ducted propeller
Thrusters{1}.A				= pi*Thrusters{1}.D^2/4;	% Disk area
Thrusters{1}.Ua_corr_sat	= 15;						% Saturation of inflow velocity correction, needed due to starting transients
Thrusters{1}.mf				= Thrusters{1}.gamma*Thrusters{1}.L*Thrusters{1}.A*Glob.rhow;	% Added mass

% Factors determining the loss surface ventilation and loss of disc area
% Run code vent_loss.m to plot the surface
Thrusters{1}.hR_lim1		= 1.4;			% hR limit for beginning ventilation if nrel > nrel_lim2
Thrusters{1}.hR_lim2 		= 1.2;			% hR limit for full ventilation if nrel > nrel_lim1
Thrusters{1}.nrel_lim1		= 1/3;			% nrel limit for beginning ventilation if hR < hR_lim1
Thrusters{1}.nrel_lim2		= 1/2;			% nrel limit for full ventilation if hR < hR_lim2
Thrusters{1}.fac1 			= 0.3;			% Loss factor for ventilation at nrel = nrel_lim2 and hR = hR_lim2			
Thrusters{1}.fac2 			= 0.1;			% Loss factor for ventilation at nrel = 1 (max) and hR = hR_lim2

% Secondary value when using "Wagner function", slower incrase to full thrust
Thrusters{1}.WhR_lim1		= 1.8;			% hR limit for beginning ventilation if nrel > nrel_lim2

% Define the loss surface matrix and vectors
Thrusters{1}.Loss_M			= [ 0 0 0 0 ; 0 0 0 0 ; 1 1 Thrusters{1}.fac1 Thrusters{1}.fac2 ; 1 1 1 1 ; 1 1 1 1 ];
Thrusters{1}.Loss_row_hR	= [ -2 -1 Thrusters{1}.hR_lim2 Thrusters{1}.hR_lim1 3 ];
Thrusters{1}.Loss_col_nrel	= [0 Thrusters{1}.nrel_lim1 Thrusters{1}.nrel_lim2 1];

% Secondary values when using Wagner function
Thrusters{1}.WLoss_row_hR	= [ -2 -1 Thrusters{1}.hR_lim2 Thrusters{1}.WhR_lim1 3 ];

% Filter for derivative of submergence
Thrusters{1}.BW_filter_cutoff		= 10*2*pi;	% Cutoff filter frequency [rad/s] 
Thrusters{1}.BW_filter_order		= 2;		% Order of butterworth filter 
 
% Butterworth filter design
[Thrusters{1}.BW_B,Thrusters{1}.BW_A] = BUTTER(Thrusters{1}.BW_filter_order,Thrusters{1}.BW_filter_cutoff,'s');

%***************************************************************************
% Multi-quadrant series data from Carlton, taken from Oosterveld

% A(K), B(K) for Ka 4-70 propeller in 19A duct, P/D=1.0, EAR=0.7
Thrusters{1}.kvec = [0:20]';
% C_T = sum(A_k*cos(k*beta) + B_k*sin(k*beta)),k = 0..20
% Propeller thrust coefficients
Thrusters{1}.a_coeff_ct =...
	[-0.10985e0 0.14064e0 0.15785e0 0.45544e-1 0.51639e-2...
	-0.25560e-2 -0.60502e-2 0.67368e-2 0.68571e-2 0.47245e-2...
	0.23591e-2 0.87912e-2 0.11968e-2 0.83808e-2 -0.82098e-3...
	0.27371e-2 -0.26121e-3 0.19133e-2 0.32290e-3 0.15223e-2 -0.10151e-2];

Thrusters{1}.b_coeff_ct =...
	[0.00000e0 -0.10583e1 0.47284e-1 0.13126e0 -0.77539e-2...
	0.93507e-1 0.92520e-2 -0.14828e-1 -0.96554e-2 0.96216e-2...
	-0.75453e-3 0.24453e-2 -0.87981e-2 0.18184e-2 0.20077e-2...
	-0.3307e-2 -0.79201e-3 -0.36311e-3 -0.19377e-2 -0.12135e-2 -0.31678e-3];

% C_TN = sum(A_k*cos(k*beta) + B_k*sin(k*beta)),k = 0..20
% Duct/Nozzle thrust coefficients. Added to C_T in the simulator.
Thrusters{1}.a_coeff_ctn =...
	[-0.11257e0 0.93340e-2  0.13788e0 0.33223e-1 0.12672e-1...
	0.14250e-1 -0.30407e-3 0.19888e-1 0.48334e-2 0.28427e-2...
	0.32326e-2 0.97693e-2 -0.28378e-3 0.29395e-2 0.53177e-3...
	0.16229e-2 -0.27265e-3 0.20276e-2 0.35477e-3 0.39082e-3 -0.92513e-3];

Thrusters{1}.b_coeff_ctn =...
	[0.0000e0 -0.26265e0 0.27587e-1 0.65262e-1 -0.40234e-2...
	0.10255e-2 -0.32045e-2 -0.21752e-2 -0.59535e-2 0.90664e-3...
	-0.10222e-2 -0.48133e-2 -0.56355e-2 -0.18248e-2 -0.20263e-2...
	-0.30382e-2 -0.11128e-2 -0.15327e-2 -0.12433e-2 -0.20069e-2 -0.48842e-3];

% C_Q=sum(A_k*cos(k*beta)+B_k*sin(k*beta)),k=0..20
% Propeller torque coefficients
Thrusters{1}.a_coeff_cq =...
	[0.35189e-1 0.24406e0 -0.7388e-2 0.2826e-1 -0.55959e-2...
	0.26558e-3 0.11368e-1 -0.47401e-1 -0.65686e-2 -0.7499e-2....
	0.12783e-2 0.46502e-2 -0.46676e-2 0.33438e-2 0.22046e-2...
	0.70034e-2 0.39147e-1 0.73719e-2 -0.94083e-3 0.60560e-2 -0.4239e-3]/10;

Thrusters{1}.b_coeff_cq =...
	[0.00000e0 -0.11717e1 0.51155e-1 0.89069e-1 -0.65670e-2...
	0.14204e0 0.77052e-2 -0.36091e-1 0.42036e-2 0.21139e-2...
	0.13095e-1 0.30961e-1 -0.99459e-2 0.17921e-1 -0.81917e-2...
	-0.78428e-3 0.72661e-2 -0.47316e-2 -0.25731e-2 0.11136e-2 -0.15470e-2]/10;

% Linear thruster characteristics, Kt(J) = a0 + a1*J, Kq(J) = b0 + b1*J
% Bad model for the ducted thruster
Thrusters{1}.a0 = 0.62471;
Thrusters{1}.a1 = -0.60357;
Thrusters{1}.b0 = 0.04852;
Thrusters{1}.b1 = -0.013657;

% Nominal thruster characteristics, for use in controller
Thrusters{1}.K_T0 = 0.789324;
Thrusters{1}.K_Q0 = 0.0588187;

%***************************************************************************
% Empty data structures, used by different thruster types. Needed to avoid Simulink errors

% 1-quadrant data fields
Thrusters{1}.Ktp = [ 0 0 0 ];
Thrusters{1}.Kqp = [ 0 0 0 ];

% Tunnel thruster data fields
Thrusters{1}.Beta_poly 		= [0 0 0 0];
Thrusters{1}.Beta_line 		= [0 0];
Thrusters{1}.Beta_lim		= [0 0];
Thrusters{1}.Kt_poly 		= [0 0 0 0];
Thrusters{1}.Kq_poly 		= [0 0 0 0];
Thrusters{1}.Sigma_lim 		= 0;
Thrusters{1}.Kt_lim 		= 0;
Thrusters{1}.Kq_lim 		= 0;

% CPP data
Thrusters{1}.B_T_vec	= zeros(1,15);
Thrusters{1}.B_T_j		= zeros(1,15);
Thrusters{1}.B_T_k		= zeros(1,15);
Thrusters{1}.B_Q_vec	= zeros(1,9);
Thrusters{1}.B_Q_j		= zeros(1,9);
Thrusters{1}.B_Q_k		= zeros(1,9);
Thrusters{1}.Cpp_Jlim	= [-1 1];
Thrusters{1}.Cpp_polylim = zeros(1,5);

%************************************************************************************************************************************************
% Thruster description 2

% Similar dimenasions as thruster 1, but 4-quadrant data for an unducted thruster

Thrusters{2} 		= Thrusters{1};
Thrusters{2}.type	= 1;			% Thruster data defined with van Lammeren 4 quadrant data
Thrusters{2}.descr 	='B-470 main propeller, P/D=1.0, EAR=0.7, 4-quadrant data'; 

Thrusters{2}.Kcc			= 0.31; 		% Cross-coupling drag coefficient

%***************************************************************************
% Multi-quadrant series data from Lammeren

% A(K), B(K) for unducted B-470 propeller, P/D=1.0, EAR=0.7
Thrusters{2}.kvec = [0:20]';
% C_T=sum(A_k*cos(k*beta)+B_k*sin(k*beta)),k=0..20
% Propeller thrust coefficients
Thrusters{2}.a_coeff_ct =...
	[.25350E-1 .17820E0 .14674E-1 .28054E-1 -.16328E-1...
	-.53041E-1 .60605E-3 .36823E-1 -.25429E-2 -.17680E-1...
	.27331E-2 .21436E-1 -.24782E-2 .12317E-2 .50980E-2...
	.78076E-2 -.37816E-2 .35353E-2 .53014E-2 .21940E-2 -.28306E-2];

Thrusters{2}.b_coeff_ct =...
	[.00000E0 -.74777E0 -.13822E-1 .10077E0 -.11318E-1...
	.47186E-1 .10666E-1 -.90239E-2 -.78452E-2 .23941E-1...
	.80787E-2 -.14942E-3 -.31925E-2 .92620E-2 .15527E-2...
	-.65683E-2 -.61655E-3 .51033E-2 -.60263E-3 -.82244E-2 -.63789E-3];

% C_TN = sum(A_k*cos(k*beta) + B_k*sin(k*beta)),k = 0..20
% Duct/Nozzle thrust coefficients. Unducted propeller, so all coefs are zero!
Thrusters{2}.a_coeff_ctn = zeros(1,21);
Thrusters{2}.b_coeff_ctn = zeros(1,21);

% C_Q=sum(A_k*cos(k*beta)+B_k*sin(k*beta)),k=0..20
% Propeller torque coefficients
Thrusters{2}.a_coeff_cq =...
	[.24645E-1 .26718E0 .16056E-1 .65822E-1 -.22497E-1...
	-.78062E-1 .24126E-2 .61475E-1 -.16065E-1 -.33291E-1...
	.12311E-1 .31123E-1 -.12559E-1 .13948E-1 .88397E-2...
	.50358E-3 -.79990E-2 .13345E-1 .11928E-1 -.13556E-2 -.70825E-2]/10;

Thrusters{2}.b_coeff_cq = ...
	[.00000E0 -.11081E1 .15909E-2 .16455E0 -.20601E-1...
	.85343E-1 .87856E-2 -.31327E-1 -.96650E-2 .43190E-1...
	.12453E-1 .95986E-3 -.79986E-2 .15073E-1 .24595E-2...
	-.16918E-1 .51603E-2 .11504E-1 -.47976E-2 -.14566E-1 .23280E-2]/10;

% Linear thruster characteristics,  Kt(J) = a0 + a1*J, Kq(J) = b0 + b1*J
% OK model for the 4 quadrant open prop
Thrusters{2}.a0 = 0.38099;
Thrusters{2}.a1 = -0.28781;
Thrusters{2}.b0 = 0.057936;
Thrusters{2}.b1 = -0.037177;

% Nominal thruster characteristics, for use in controller
Thrusters{2}.K_T0 = 0.445085;
Thrusters{2}.K_Q0 = 0.0665984;


%************************************************************************************************************************************************
% Thruster description 3

% Similar dimensions as thruster 1, but using 1 quadrant prop data
% The 4-quadrant data is not used
Thrusters{3} 		= Thrusters{2};
Thrusters{3}.type	= 2;	% Thruster data defined with conventional thrust/torque coefficients
Thrusters{3}.descr 	='B-470 main propeller, P/D=1.0, EAR=0.7, one-quadrant data'; 

%***************************************************************************
% Wageningen B-series propeller data, one quadrant. From the function wageningen.m with PD = 1, Z = 4 and EAR = 0.7
% Thrust and torque coefficients given as 2nd order polynomial in J, in order to avoid trouble at n~=0
% Higher-order polynomials will give trouble for low n, since J -> inf
Thrusters{3}.Ktp = [ -0.1060   -0.3246    0.4594 ];
Thrusters{3}.Kqp = [ -0.0186   -0.0399    0.0680 ];

% Linear thruster characteristics, Kt(J) = a0 + a1*J, Kq(J) = b0 + b1*J
% Good model for the 1 quadrant data
Thrusters{3}.a0 = 0.44594;
Thrusters{3}.a1 = -0.38396;
Thrusters{3}.b0 = 0.065638;
Thrusters{3}.b1 = -0.050316;

% Nominal thruster characteristics, for use in controller
Thrusters{3}.K_T0 = Thrusters{3}.Ktp(3);
Thrusters{3}.K_Q0 = Thrusters{3}.Kqp(3);

%************************************************************************************************************************************************
% Thruster description 4

% Similar dimensions as thruster 1, but using the nominal characteristics
% The 4-quadrant data is not used
Thrusters{4} 		= Thrusters{3};
Thrusters{4}.type	= 2;	% Thruster data defined with conventional thrust/torque coefficients
Thrusters{4}.descr 	='B-470 main propeller, P/D=1.0, EAR=0.7, nominal characteristics KT0 and KQ0'; 

%***************************************************************************
% Wageningen B-series propeller data, nominal characteristict. From the function wageningen.m with PD = 1, Z = 4 and EAR = 0.7
% Only K_T0 and KQ_0 are given
Thrusters{4}.Ktp = [ 0 0 0.4594 ];
Thrusters{4}.Kqp = [ 0 0 0.0680 ];

% Linear thruster characteristics, Kt(J) = a0 + a1*J, Kq(J) = b0 + b1*J
% Good model for the 1 quadrant data
Thrusters{4}.a0 = 0.44594;
Thrusters{4}.a1 = 0;
Thrusters{4}.b0 = 0.065638;
Thrusters{4}.b1 = 0;

% Nominal thruster characteristics, for use in controller
Thrusters{4}.K_T0 = Thrusters{4}.Ktp(3);
Thrusters{4}.K_Q0 = Thrusters{4}.Kqp(3);


%************************************************************************************************************************************************
% Thruster description 5
% Many fields left empty, this is to avoid errors in Simulink: Using one common thruster representation

Thrusters{5}.descr 			= 'Tunnel thruster, P/D = 1.0255';
Thrusters{5}.type			= 3;			% Tunnel thruster data based on cavitation number

% Main data
Thrusters{5}.Z				= 4;			% Number of blades
Thrusters{5}.D				= 2;			% Diameter
Thrusters{5}.EAR			= 0.7;			% EAR = A_E/A_0, blade area ratio
Thrusters{5}.PD				= 1.0255;		% Pitch/diameter ratio
Thrusters{5}.RPM_p_max		= 240;			% Propeller max RPM
Thrusters{5}.J_p			= 1100;			% Rotational inertia of propeller, shaft and gears, seen from propeller

% Position and orientation
Thrusters{5}.r_p			= [32 -5 4]';% thruster position(x,y,z). This is to be redefined when loading the thrusters
Thrusters{5}.alpha			= pi/2;			% thruster direction [rad], zero for thrust ahead. If rotateable, this is the inital value
Thrusters{5}.fixed_dir		= 1;			% 1 for fixed direction, 0 for rotateable thruster
Thrusters{5}.control_weight	= 1;			% Weight for thrust allocation routine, [0,1]

% Propeller motor, these data are rather arbitrary, should be checked
Thrusters{5}.RPM_m_max		= 1000;			% motor RPM max speed
Thrusters{5}.P_max			= 1E6 ;			% Max motor power [W]
Thrusters{5}.Q_max			= 3E4;			% Max motor torque [Nm]
Thrusters{5}.T_m 			= 0.1;			% motor time constant for 1st order model

% Azimuth motor, only for rotating thrusters. Leave dummy values for non-rotateable thrusters
Thrusters{5}.T_dir			= 1;			% rotateable thruster time constant for 1st order model
Thrusters{5}.rate_dir_max	= 20*pi/180;	% rotateable thruster max rotation rate [rad/s]

% Pitch motor, only for CP thrusters. 
Thrusters{5}.T_pitch		= 0.3;			% Time constant for pitch 1st order dynamics 
Thrusters{5}.rate_PD_max	= 4/5;			% Pitch rate saturation [PD/sec] 
Thrusters{5}.PD_lim			= [-2 2];		% Validity range for PD, specific for this propeller.

% Calculate motor rate and gear ratio
Thrusters{5}.gear_ratio		= Thrusters{5}.RPM_m_max/Thrusters{5}.RPM_p_max; % Gear ratio
Thrusters{5}.J_m 			= Thrusters{5}.J_p/(Thrusters{5}.gear_ratio^2); % Rotational inertia seen from motor

Thrusters{5}.RPM_m_T		= 5;			% motor RPM max rate: 5 seconds from 0 to max
Thrusters{5}.RPM_m_rate		= Thrusters{1}.RPM_m_max/Thrusters{1}.RPM_m_T; % Max motor rate     

% Hydrodynamic data
Thrusters{5}.w				= [0 0 0];	% wake factor
Thrusters{5}.t				= 0;			% thrust deduction
Thrusters{5}.Kcc			= 1.125; 		% Cross-coupling drag coefficient, not appliccable to tunnel thruster
Thrusters{5}.Q_loss			= 0.65;			% Torque loss factor

% Data for hydrodynamic mass-damper model
Thrusters{5}.gamma			= 1;						% Added mass parameter
Thrusters{5}.L				= 10;						% Characteristic length, equal to tunnel length for tunnel thruster
Thrusters{5}.A				= pi*Thrusters{5}.D^2/4;	% Disk area
Thrusters{5}.Ua_corr_sat	= 15;						% Saturation of inflow velocity correction, needed due to starting transients
Thrusters{5}.mf				= Thrusters{5}.gamma*Thrusters{5}.L*Thrusters{5}.A*Glob.rhow;	% Added mass

% Loss polynomial for relative radial velocity at tunnel exit:
Thrusters{5}.Beta_poly 		= [-0.664063 2.38542 -2.39792 1];
Thrusters{5}.Beta_line 		= [0.35 -0.01];
Thrusters{5}.Beta_lim		= [1.2 0.7];
             
% Factors determining the loss surface ventilation and loss of disc area
% Run code vent_loss.m to plot the surface
Thrusters{5}.hR_lim1		= 1.4;			% hR limit for beginning ventilation if nrel > nrel_lim2
Thrusters{5}.hR_lim2 		= 1.2;			% hR limit for full ventilation if nrel > nrel_lim1
Thrusters{5}.nrel_lim1		= 1/3;			% nrel limit for beginning ventilation if hR < hR_lim1
Thrusters{5}.nrel_lim2		= 1/2;			% nrel limit for full ventilation if hR < hR_lim2
Thrusters{5}.fac1 			= 0.3;			% Loss factor for ventilation at nrel = nrel_lim2 and hR = hR_lim2			
Thrusters{5}.fac2 			= 0.1;			% Loss factor for ventilation at nrel = 1 (max) and hR = hR_lim2

% Secondary value when using "Wagner function", slower increase to full thrust
Thrusters{5}.WhR_lim1		= 1.8;			% hR limit for beginning ventilation if nrel > nrel_lim2

% Define the loss surface matrix and vectors
Thrusters{5}.Loss_M			= [ 0 0 0 0 ; 0 0 0 0 ; 1 1 Thrusters{5}.fac1 Thrusters{5}.fac2 ; 1 1 1 1 ; 1 1 1 1 ];
Thrusters{5}.Loss_row_hR	= [ -2 -1 Thrusters{5}.hR_lim2 Thrusters{5}.hR_lim1 3 ];
Thrusters{5}.Loss_col_nrel	= [0 Thrusters{5}.nrel_lim1 Thrusters{5}.nrel_lim2 1];

% Secondary values when using Wagner function
Thrusters{5}.WLoss_row_hR	= [ -2 -1 Thrusters{5}.hR_lim2 Thrusters{5}.WhR_lim1 3 ];

% Filter for derivative of submergence
Thrusters{5}.BW_filter_cutoff		= 10*2*pi;	% Cutoff filter frequency [rad/s] 
Thrusters{5}.BW_filter_order		= 2;		% Order of butterworth filter 
 
% Butterworth filter design
[Thrusters{5}.BW_B,Thrusters{5}.BW_A] = BUTTER(Thrusters{5}.BW_filter_order,Thrusters{5}.BW_filter_cutoff,'s');


%***************************************************************************
% Thruster characteristics, Kt and Kq as function of cavitation number.
% 3rd degree polynomial:
Thrusters{5}.Kt_poly = [6.66667 -8.91667 3.69167 0];
Thrusters{5}.Kq_poly = [0.616667 -1.00167 0.490667 0];
 
% Limit values for high sigma:
Thrusters{5}.Sigma_lim = 0.6;
Thrusters{5}.Kt_lim = 0.445;
Thrusters{5}.Kq_lim = 0.067;

% Nominal thruster characteristics, for use in controller
Thrusters{5}.K_T0 = Thrusters{5}.Kt_lim;
Thrusters{5}.K_Q0 = Thrusters{5}.Kq_lim;

%***************************************************************************
% Multi-quadrant series data, left empty

Thrusters{5}.kvec = [0:20]';
Thrusters{5}.a_coeff_ct = zeros(1,21);
Thrusters{5}.b_coeff_ct = zeros(1,21);
Thrusters{5}.a_coeff_ctn = zeros(1,21);
Thrusters{5}.b_coeff_ctn = zeros(1,21);
Thrusters{5}.a_coeff_cq = zeros(1,21);
Thrusters{5}.b_coeff_cq = zeros(1,21);

% Linear thruster characteristics, Kt(J) = a0 + a1*J, Kq(J) = b0 + b1*J
% Bad model for the ducted thruster
Thrusters{5}.a0 = 0;
Thrusters{5}.a1 = 0;
Thrusters{5}.b0 = 0;
Thrusters{5}.b1 = 0;

% Wageningen data
Thrusters{5}.Ktp = [ 0 0 0 ];
Thrusters{5}.Kqp = [ 0 0 0 ];

% CPP data
Thrusters{5}.B_T_vec	= zeros(1,15);
Thrusters{5}.B_T_j		= zeros(1,15);
Thrusters{5}.B_T_k		= zeros(1,15);
Thrusters{5}.B_Q_vec	= zeros(1,9);
Thrusters{5}.B_Q_j		= zeros(1,9);
Thrusters{5}.B_Q_k		= zeros(1,9);
Thrusters{5}.Cpp_Jlim	= [-1 1];
Thrusters{5}.Cpp_polylim = zeros(1,5);

