%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
%
% Vessel_results.m
%
% Project:	"Marine Cybernetics Simulator: MCSim"
%
% Abstract:	Present MCSim simulation data from "Saved" structure in workspace.
%			"Saved" structure can be from the last simulation or loaded from
%			a stored mat-file into workspace.
%
% Inputs:	-
%
% Outputs:	-
%	
% Calls:	-
%		
% Author:	yvind Smogeli, Summer 2003
%
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 

% Change window size for big plots
window_size = [100   100   500   800];

% Position for NED position and velocity/direction plots
window_pos_NED = [680 550 560 400];	%[360 514 560 420] Matlab default
window_pos_vel = [680 50 560 400];	%[360 514 560 420] Matlab default

disp('Displaying data from "Saved" structure in Workspace')
		
nsteps = length(Saved.t);

% Total speed
vtot = sqrt(Saved.Nu(:,1).^2 + Saved.Nu(:,2).^2);

% Direction
for ii = 2:nsteps
	Saved.Etashift(ii-1,:) = Saved.Eta(ii,:);
end

Saved.Etashift(nsteps,:) = Saved.Etashift(nsteps-1,:);
deltaEta = Saved.Etashift-Saved.Eta;
direction = atan2(deltaEta(:,2),deltaEta(:,1))*180/pi;

% % Result checking
% for k = 1:6
%     
%     Eta_WF_mean(k) = mean(Saved.Eta_WF(:,k));
%     Nu_WF_mean(k) = mean(Saved.Nu_WF(:,k));
%     Nu_d_WF_mean(k) = mean(Saved.Nu_d_WF(:,k));
%     
% end
% 
% disp(' ')
% disp('Mean values of WF motion:')
% disp(['Eta_WF  : ', num2str(Eta_WF_mean)])
% disp(['Nu_WF   : ', num2str(Nu_WF_mean)])
% disp(['Nu_d_WF : ', num2str(Nu_d_WF_mean)])


etafig = figure;
subplot(6,1,1)
plot(Saved.t, Saved.Eta(:,1), 'k-', Saved.t, Saved.Eta_WF(:,1), 'b-', Saved.t, Saved.Eta_LF(:,1), 'r-')
title('\eta [m, deg] (black = LF + WF, blue = WF, red = LF)')
ylabel('x')
subplot(6,1,2)
plot(Saved.t, Saved.Eta(:,2), 'k-', Saved.t, Saved.Eta_WF(:,2), 'b-', Saved.t, Saved.Eta_LF(:,2), 'r-')
ylabel('y')
subplot(6,1,3)
plot(Saved.t, Saved.Eta(:,3), 'k-', Saved.t, Saved.Eta_WF(:,3), 'b-', Saved.t, Saved.Eta_LF(:,3), 'r-')
ylabel('z')
subplot(6,1,4)
plot(Saved.t, Saved.Eta(:,4)*180/pi, 'k-', Saved.t, Saved.Eta_WF(:,4)*180/pi, 'b-', Saved.t, Saved.Eta_LF(:,4)*180/pi, 'r-')
ylabel('\phi')
subplot(6,1,5)
plot(Saved.t, Saved.Eta(:,5)*180/pi, 'k-', Saved.t, Saved.Eta_WF(:,5)*180/pi, 'b-', Saved.t, Saved.Eta_LF(:,5)*180/pi, 'r-')
ylabel('\theta')
subplot(6,1,6)
plot(Saved.t, Saved.Eta(:,6)*180/pi, 'k-', Saved.t, Saved.Eta_WF(:,6)*180/pi, 'b-', Saved.t, Saved.Eta_LF(:,6)*180/pi, 'r-')
ylabel('\psi')
xlabel('t')
set(gcf,'Position',window_size);  %Enlarge window



% figure
% subplot(6,1,1)
% plot(Saved.t, Saved.Nu(:,1), 'k-', Saved.t, Saved.Nu_WF(:,1), 'b-', Saved.t, Saved.Nu_LF(:,1), 'r-')
% title('\nu [m/s, rad/s] (black = LF + WF, blue = WF, red = LF)')
% ylabel('u')
% subplot(6,1,2)
% plot(Saved.t, Saved.Nu(:,2), 'k-', Saved.t, Saved.Nu_WF(:,2), 'b-', Saved.t, Saved.Nu_LF(:,2), 'r-')
% ylabel('v')
% subplot(6,1,3)
% plot(Saved.t, Saved.Nu(:,3), 'k-', Saved.t, Saved.Nu_WF(:,3), 'b-', Saved.t, Saved.Nu_LF(:,3), 'r-')
% ylabel('w')
% subplot(6,1,4)
% plot(Saved.t, Saved.Nu(:,4)*180/pi, 'k-', Saved.t, Saved.Nu_WF(:,4)*180/pi, 'b-', Saved.t, Saved.Nu_LF(:,4)*180/pi, 'r-')
% ylabel('p')
% subplot(6,1,5)
% plot(Saved.t, Saved.Nu(:,5)*180/pi, 'k-', Saved.t, Saved.Nu_WF(:,5)*180/pi, 'b-', Saved.t, Saved.Nu_LF(:,5)*180/pi, 'r-')
% ylabel('q')
% subplot(6,1,6)
% plot(Saved.t, Saved.Nu(:,6)*180/pi, 'k-', Saved.t, Saved.Nu_WF(:,6)*180/pi, 'b-', Saved.t, Saved.Nu_LF(:,6)*180/pi, 'r-')
% ylabel('r')
% xlabel('t')
% set(gcf,'Position',window_size);  %Enlarge window
% 

% figure
% subplot(6,1,1)
% plot(Saved.t, Saved.Nu_d(:,1), 'k-', Saved.t, Saved.Nu_d_WF(:,1), 'b-', Saved.t, Saved.Nu_d_LF(:,1), 'r-')
% title('\nu_d [m/s^2, rad/s^2] (black = LF + WF, blue = WF, red = LF)')
% ylabel('u_d')
% subplot(6,1,2)
% plot(Saved.t, Saved.Nu_d(:,2), 'k-', Saved.t, Saved.Nu_d_WF(:,2), 'b-', Saved.t, Saved.Nu_d_LF(:,2), 'r-')
% ylabel('v_d')
% subplot(6,1,3)
% plot(Saved.t, Saved.Nu_d(:,3), 'k-', Saved.t, Saved.Nu_d_WF(:,3), 'b-', Saved.t, Saved.Nu_d_LF(:,3), 'r-')
% ylabel('w_d')
% subplot(6,1,4)
% plot(Saved.t, Saved.Nu_d(:,4)*180/pi, 'k-', Saved.t, Saved.Nu_d_WF(:,4)*180/pi, 'b-', Saved.t, Saved.Nu_d_LF(:,4)*180/pi, 'r-')
% ylabel('p_d')
% subplot(6,1,5)
% plot(Saved.t, Saved.Nu_d(:,5)*180/pi, 'k-', Saved.t, Saved.Nu_d_WF(:,5)*180/pi, 'b-', Saved.t, Saved.Nu_d_LF(:,5)*180/pi, 'r-')
% ylabel('q_d')
% subplot(6,1,6)
% plot(Saved.t, Saved.Nu_d(:,6)*180/pi, 'k-', Saved.t, Saved.Nu_d_WF(:,6)*180/pi, 'b-', Saved.t, Saved.Nu_d_LF(:,6)*180/pi, 'r-')
% ylabel('r_d')
% xlabel('t')
% set(gcf,'Position',window_size);  %Enlarge window
% 



% figure
% subplot(2,1,1)
% plot(Saved.t,vtot)
% title('V_{tot} [m/s]')
% subplot(2,1,2)
% plot(Saved.t,direction)
% title('direction [deg]')
% set(gcf,'Position',window_pos_vel);  
% 
figure
plot(Saved.Eta_WF(:,2)+Saved.Eta_LF(:,2),Saved.Eta_WF(:,1)+Saved.Eta_LF(:,1),'b')
hold on
plot(Saved.Eta_LF(:,2),Saved.Eta_LF(:,1),'r')
title('Position in NED (blue = LF+WF, red = LF)')
xlabel('y')
ylabel('x')
grid on;
set(gcf,'Position',window_pos_NED);  

figure
plot(Saved.Eta_WF(2100:20000,2)+Saved.Eta_LF(2100:20000,2),Saved.Eta_WF(2100:20000,1)+Saved.Eta_LF(2100:20000,1),'b')
hold on
plot(Saved.Eta_LF(2100:20000,2),Saved.Eta_LF(2100:20000,1),'r')
title('Position in NED (blue = LF+WF, red = LF)')
xlabel('y')
ylabel('x')
grid on;
set(gcf,'Position',window_pos_NED);  


figure
subplot(3,1,1)
plot(Saved.t, Saved.Tau_T(:,1))
title('Thruster force [N, Nm]')
ylabel('Surge [N]')
grid on;
subplot(3,1,2)
plot(Saved.t, Saved.Tau_T(:,2))
ylabel('Sway [N]')
grid on;
subplot(3,1,3)
plot(Saved.t, Saved.Tau_T(:,6))
ylabel('Yaw [Nm]')
grid on;
xlabel('t')
set(gcf,'Position',window_size);  %Enlarge window


if Sim.LF_model == 1 & Sim.Force_plots == 1
	
	
	figure
	subplot(6,1,1)
	plot(Saved.t, Saved.F_current(:,1))
	title('Current force [N]')
	ylabel('F1')
	subplot(6,1,2)
	plot(Saved.t, Saved.F_current(:,2))
	ylabel('F2')
	subplot(6,1,3)
	plot(Saved.t, Saved.F_current(:,3))
	ylabel('F3')
	subplot(6,1,4)
	plot(Saved.t, Saved.F_current(:,4))
	ylabel('F4')
	subplot(6,1,5)
	plot(Saved.t, Saved.F_current(:,5))
	ylabel('F5')
	subplot(6,1,6)
	plot(Saved.t, Saved.F_current(:,6))
	ylabel('F6')
	xlabel('t')
	set(gcf,'Position',window_size);  %Enlarge window

	
	figure
	subplot(6,1,1)
	plot(Saved.t, Saved.F_wind(:,1))
	title('Wind force [N]')
	ylabel('F1')
	subplot(6,1,2)
	plot(Saved.t, Saved.F_wind(:,2))
	ylabel('F2')
	subplot(6,1,3)
	plot(Saved.t, Saved.F_wind(:,3))
	ylabel('F3')
	subplot(6,1,4)
	plot(Saved.t, Saved.F_wind(:,4))
	ylabel('F4')
	subplot(6,1,5)
	plot(Saved.t, Saved.F_wind(:,5))
	ylabel('F5')
	subplot(6,1,6)
	plot(Saved.t, Saved.F_wind(:,6))
	ylabel('F6')
	xlabel('t')
	set(gcf,'Position',window_size);  %Enlarge window
	
end

% Show the NED position figure, Estimated, measured and desired
figure(etafig)
figure;
subplot(3,1,1);
plot(Saved.t, Eta_meas_out(:,1), 'b-', Saved.t, Eta_hat_out(:,1), 'g-', Saved.t, Eta_des_out(:,1), 'r-')
% axis([0 180 -2 1]);
title('Position [m, deg] (blue = Measured, green = Estimated, red = Desired)')
ylabel('Surge [m]');
grid on;

subplot(3,1,2);
plot(Saved.t, Eta_meas_out(:,2), 'b-', Saved.t, Eta_hat_out(:,2), 'g-', Saved.t, Eta_des_out(:,1), 'r-')
% axis([0 180 -1 0]);
ylabel('Sway [m]');
grid on;

subplot(3,1,3);
plot(Saved.t, (180/pi)*Eta_meas_out(:,6), 'b-', Saved.t, (180/pi)*Eta_hat_out(:,3), 'g-', Saved.t, (180/pi)*Eta_des_out(:,1), 'r-')
% axis([0 180 -5 10]);
ylabel('Yaw [deg]');
grid on;


% PID - GAINS
figure;
subplot(3,1,1);
plot(Saved.t, P_gains(:,1), 'b-', Saved.t, D_gains(:,1), 'g-', Saved.t, I_gains(:,1), 'r-')
% axis([0 180 -0.5 1]);
title('PID gains [N] (blue = P, red = I, green = D)')
ylabel('Surge');
grid on;

subplot(3,1,2);
plot(Saved.t, P_gains(:,2), 'b-', Saved.t, D_gains(:,2), 'g-', Saved.t, I_gains(:,2), 'r-')
% axis([0 180 -0.1 0.1]);
ylabel('Sway');
grid on;

subplot(3,1,3);
plot(Saved.t, P_gains(:,3), 'b-', Saved.t, D_gains(:,3), 'g-', Saved.t, I_gains(:,3), 'r-')
% axis([0 180 -0.05 0.05]);
ylabel('Yaw');
grid on;

% Estimated and desired positions;
figure;
subplot(3,1,1);
plot(Saved.t, Eta_hat_out(:,1), 'g-', Saved.t, Eta_des_out(:,1), 'r-')
% axis([0 180 -2 1]);
title('Position [m, deg] (green = Estimated, red = Desired)')
ylabel('Surge [m]');
grid on;

subplot(3,1,2);
plot(Saved.t, Eta_hat_out(:,2), 'g-', Saved.t, Eta_des_out(:,2), 'r-')
% axis([0 180 -0.8 -0.2]);
ylabel('Sway [m]');
grid on;

subplot(3,1,3);
plot(Saved.t, (180/pi)*Eta_hat_out(:,3), 'g-', Saved.t, (180/pi)*Eta_des_out(:,3), 'r-')
% axis([0 180 -2 10]);
ylabel('Yaw [deg]');
grid on;


% Estimated and desired velocities
figure;
subplot(3,1,1);
plot(Saved.t, Nu_hat_out(:,1), 'g-', Saved.t, Nu_des_out(:,1), 'r-')
% axis([0 180 -0.2 0.2]);
title('Velocity [m/s, rad/s] (red = Desired, green = Estimated)')
ylabel('Surge [m/s]');
grid on;

subplot(3,1,2);
plot(Saved.t, Nu_hat_out(:,2), 'g-', Saved.t, Nu_des_out(:,2), 'r-')
% axis([0 180 -0.01 0.01]);
ylabel('Sway [m/s]');
grid on;

subplot(3,1,3);
plot(Saved.t, (180/pi)*Nu_hat_out(:,3), 'g-', Saved.t, (180/pi)*Nu_des_out(:,3), 'r-')
% axis([0 180 -5 10]);
ylabel('Yaw [deg/s]');
grid on;

% Estimated and measured velocities
figure;
subplot(3,1,1);
plot(Saved.t, Nu_meas_out(:,1), 'r-', Saved.t, Nu_hat_out(:,1), 'g-')
% axis([0 180 -0.2 0.2]);
title('Velocity [m/s, rad/s] (red = measured, green = Estimated)')
ylabel('Surge [m/s]');
grid on;

subplot(3,1,2);
plot(Saved.t, Nu_meas_out(:,2), 'r-', Saved.t, Nu_hat_out(:,2), 'g-')
% axis([0 180 -0.01 0.01]);
ylabel('Sway [m/s]');
grid on;

subplot(3,1,3);
plot(Saved.t, (180/pi)*Nu_meas_out(:,6), 'r-', Saved.t, (180/pi)*Nu_hat_out(:,3), 'g-')
% axis([0 180 -5 10]);
ylabel('Yaw [deg/s]');
grid on;


% 
% % X and Y current velocities
% figure;
% subplot(2,1,1);
% plot(Saved.t, Current_meas_out(:,1))
% % axis([0 180 -0.2 0.2]);
% title('Current velocities in x and y directions')
% ylabel('x [m/s]');
% grid on;
% 
% subplot(2,1,2);
% plot(Saved.t, Current_meas_out(:,2))
% % axis([0 180 -0.01 0.01]);
% ylabel('y [m/s]');
% grid on;
% % 
% 
% 
% % X and Y wind
% figure;
% subplot(2,1,1);
% plot(Saved.t, Wind_meas_out(:,1))
% % axis([0 180 -0.2 0.2]);
% title('Wind velocities in x and y directions')
% ylabel('x [m/s]');
% grid on;
% 
% subplot(2,1,2);
% plot(Saved.t, Wind_meas_out(:,2))
% % axis([0 180 -0.01 0.01]);
% ylabel('y [m/s]');
% grid on;