%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
%
% Controls.m
%
% Project:	"Marine Cybernetics Simulator: MCSim"
%
% Abstract:	Control settings, to be edited by user
% 
% Inputs:	-
%
% Outputs:	-
%	
% Calls:	-
%
% Author:	yvind Smogeli, Summer 2003
%
% Changes:	
%
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 


%************************************************************************************************************************************************************************
% Local thruster control

% Thruster controller settings
Control.Thruster{1}.Type 					= 2;								% Controller if NOT in Anti-Spin mode
Control.Thruster{1}.Types{1}				= 'Shaft speed feedback control'; 	% 1 - Shaft speed feedback control
Control.Thruster{1}.Types{2}				= 'Torque feedforward control';		% 2 - Torque feedforward control
Control.Thruster{1}.Types{3}				= 'Power feedback control';			% 3 - Power feedback control
Control.Thruster{1}.Types{4}				= 'Hybrid power/torque control';	% 4 - Hybrid power/torque control
Control.Thruster{1}.Types{5}				= 'Feedforward control';			% 5 - Feedforward control, with specified motor torque
	
% Thrust decuction number, to be compensated for
Control.Thruster{1}.thrust_deduc			= Par.Thruster{1}.t;

% Speed PID controller
Control.Thruster{1}.PID.k					= 0.5*14000;	% Proportional gain 14000 
Control.Thruster{1}.PID.ti					= 3;			% Integral time constant 3
Control.Thruster{1}.PID.td					= 0.01;			% Derivative time constant 0.01
Control.Thruster{1}.PID.windup				= 0.8;			% Integral windup limit, percent of max torque 0.8
Control.Thruster{1}.PID.T_td_filter 		= 0.05;          % Derivative filter time constant 0.05

% Hybrid power/torque control weight function: alpha(n) = exp(-k*abs(pn)^r), Qc = Qq*alpha + Qp*(1- alpha)
Control.Thruster{1}.Hybrid.r				= 5;
Control.Thruster{1}.Hybrid.p				= 0.12;
Control.Thruster{1}.Hybrid.k				= 4;

% Feedforward control 
Control.Thruster{1}.Q_ref					= 15E3;			% Motor control torque if feedforward motor control (Type = 5)

%-------------------------------------------------------------------------------------------------------------------------
% Thruster 2,3,4,5 = 1
% This is needed because 5 thruster units are defined in the Simulink simulator. 
Control.Thruster{2} = Control.Thruster{1};
Control.Thruster{3} = Control.Thruster{1};
Control.Thruster{4} = Control.Thruster{1};
Control.Thruster{5} = Control.Thruster{1};


%************************************************************************************************************************************************************************
% Thrust allocation, only used if Sim.Thrusters == 1 and Sim.Thrust_alloc == 1

Control.Alloc.Type				= 2;	% Allocation type:
Control.Alloc.Types{1}			= 'No allocation, using feedforward thrust setpoints, edit simulink file!';	
Control.Alloc.Types{2}			= 'Allocation for NON-rotateable thrusters';	
Control.Alloc.Types{3}          = 'Control Allocation: Kjell Erik Larsen';

if Sim.Thrust_alloc == 0 & Control.Alloc.Type ~= 1
	Control.Alloc.Type = 1;
	disp(' ')
	disp('Thrust allocation changed to pure feedforward because Sim.Thrust_alloc = 0')
	disp(' ')
end

%******************************													
% Feedforward thrust reference, for Control.Alloc.Type = 1
%Control.Alloc.Tref				= 75E3*[1 1 1 1 1]; % Tunnel
Control.Alloc.Tref				= 250E3*[1 1 1 1 1]; % Main

% Feedforward reference signal
Control.Alloc.Feedforward.type	= 1; % 1 for constant, 2 for ramp from Tref to -0.2*Tref, 3 for sinusoidal

%************************************************************************************************************************************************************************
% Vessel controller settings, only used if Sim.Vessel_Control == 1

Control.Type					= 4;										% Control type:
Control.Types{1}				= 'Thrust vector feedforward';				% 1 - Thrust vector feedforward, edited in simulink file
Control.Types{2}				= 'PID DP controller';						% 2 - PID DP controller 
Control.Types{3}				= 'Manually tunable PID DP controller';		% 3 - Manually tunable PID DP controller
Control.Types{4}				= 'Horizontal-plane DP controller';			% 4 - Horizontal-plane DP controller

													
% Desired positions and desired heading, [x y psi] and step time
Control.Vessel.pos_init			= [0 0 0];			% Initial setpoint for vessel
Control.Vessel.pos_d			= [0 0 0];         	% Sets desired setpoint for vessel. Station-keeping when set to zero.
Control.Vessel.step_time		= 100;             	% Sets step time for the change in desired position.

%******************************													
% Thrust reference feedforward settings
Control.FF.ramp_start			= 10;							% Start time for ramping up thrust reference
Control.FF.ramp_rate			= [0 10E3 0];					% Rate of thrust rampup [surge, sway, yaw]
Control.FF.max_ref				= [600E3 600E3 600E3*5];		% Max reference values
	


%******************************													
% Max thrust vector

Control.Tau_max					= [3 3 27];	%[1e6, 1e6, 1e12];


% Thrust reference feedforward settings
Control.FF.ramp_start			= 10;							% Start time for ramping up thrust reference
Control.FF.ramp_rate			= [0 10E3 0];					% Rate of thrust rampup [surge, sway, yaw]
Control.FF.max_ref				= [600E3 600E3 600E3*5];		% Max reference values
	
%******************************													
% PID DP settings
%Control.PID.zeta				= [1.2 1.2 1.2];	% Design damping ratio [-] [surge sway yaw]
Control.PID.zeta				= [2 2 2];	% Design damping ratio [-] [surge sway yaw]
Control.PID.T_n					= [15 15 20];	% Design time constant [s] [surge sway yaw]
Control.PID.K_m					= [0 0 0];		% Acceleration feedback constants [surge sway yaw]
Control.PID.T_i_fac				= [10 10 10];	% Factor by which the integral time constant is slower than the natural frequency


Control.PID.Ki_sat				= 0.8*Control.Tau_max;	% Saturation of integral term

Control.PID.M					= diag(Glob.H36*Par.Vessel.M*Glob.H36')';	% 3DOF mass matrix main diagonal values from vessel model
Control.PID.D					= diag(Glob.H36*Par.Vessel.DL*Glob.H36')';	% 3DOF linear damping matrix main diagonal values from vessel model

% Controller design
Control.PID.omega_n				= 2*pi./Control.PID.T_n;
Control.PID.Kp					= (Control.PID.M + Control.PID.K_m).*Control.PID.omega_n.^2;									% Proportional gain vector
Control.PID.Kd					= (Control.PID.M + Control.PID.K_m)*2.*Control.PID.zeta.*Control.PID.omega_n - Control.PID.D;	% Derivative gain vector
Control.PID.Ki					= Control.PID.omega_n.*Control.PID.Kp./Control.PID.T_i_fac;										% Integral gain vector


					
%******************************													
% Horizontal-plane DP settings

% -------------------------------------------------------------------------
% Model reference feedforward control action:

% Matrix of inertia and damping for 3DOF

Control.Vessel_3_DOF.M =     [Par.Vessel.M(1,1) Par.Vessel.M(1,2) Par.Vessel.M(1,6);
                              Par.Vessel.M(2,1) Par.Vessel.M(2,2) Par.Vessel.M(2,6);
                              Par.Vessel.M(6,1) Par.Vessel.M(6,2) Par.Vessel.M(6,6)];
 
Control.Vessel_3_DOF.D =     [Par.Vessel.DL(1,1) Par.Vessel.DL(1,2) Par.Vessel.DL(1,6);
                              Par.Vessel.DL(2,1) Par.Vessel.DL(2,2) Par.Vessel.DL(2,6);
                              Par.Vessel.DL(6,1) Par.Vessel.DL(6,2) Par.Vessel.DL(6,6)];
                          

                          
% -------------------------------------------------------------------------
% PD-control action: (Method as described in Fossen (2002)).

% Inertia and damping vectors
Control.Vessel_3_DOF.M_vect = [Control.Vessel_3_DOF.M(1,1) Control.Vessel_3_DOF.M(2,2) Control.Vessel_3_DOF.M(3,3)];
Control.Vessel_3_DOF.D_vect = [Control.Vessel_3_DOF.D(1,1) Control.Vessel_3_DOF.D(2,2) Control.Vessel_3_DOF.D(3,3)];

% Design parameters, used for determination of PD-gains.
Control.Vessel.PID.T     =  [93.67 142.3 82.4];   			% Design time constants in surge, sway and yaw
Control.Vessel.PID.omg_n =  2*pi./Control.Vessel.PID.T; % Natural frequency in surge, sway and yaw
Control.Vessel.PID.zeta  =  [1.58 1.66 1.09]; 			% Design damping ratio in surge, sway and yaw
Control.Vessel.PID.Ifact =  [3.41 1.98 25.2];  			% Factor by which the time integral is slower than the natural frequency

% PD-gains:

% Proportional Gain
Control.Vessel.P_Gain.Gp = Control.Vessel_3_DOF.M_vect.*Control.Vessel.PID.omg_n.^2;          

% Derivate Gain
Control.Vessel.D_Gain.Gd = 2.*Control.Vessel.PID.zeta.*Control.Vessel.PID.omg_n.*Control.Vessel_3_DOF.M_vect-Control.Vessel_3_DOF.D_vect;                                     


% -------------------------------------------------------------------------
% Integral action:

Control.Vessel.Int.antiwindup.A_w = [0 0 0; 0 0 0; 0 0 0];       % Anti-windup precaution matrix

% Integrator gain matrix
Control.Vessel.I_Gain.Gi = (-1).*Control.Vessel.PID.omg_n.*Control.Vessel.P_Gain.Gp./Control.Vessel.PID.Ifact; 
% 
% Control.Vessel.P_Gain.Gp = 240*Control.Vessel.P_Gain.Gp + [0,0,200];
% Control.Vessel.D_Gain.Gd = 96*Control.Vessel.D_Gain.Gd + [0,0,1000];
% Control.Vessel.I_Gain.Gi = 360*Control.Vessel.I_Gain.Gi;

Control.Vessel.P_Gain.Gp = [10 3 30];
Control.Vessel.D_Gain.Gd = [30 30 100];
Control.Vessel.I_Gain.Gi = -[0.1 0.4 2];
%************************************************************************************************************************************************************************
% Reference model settings, only for use with DP

Control.Vessel.max_vel_d = [0.15 0.15 0.15];    % Sets desired maximum velocity for vessel in surge, svai and yaw
Control.Vessel.max_acc_d = [0.04 0.04 0.04];    % Sets desired maximum acceleration for vessel in surge, svai and yaw


% Design parameters in reference model

Control.Vessel.Ref.Design_damp = [0.96 0.96 0.97];                % Relative damping in reference model 
Control.Vessel.Ref.Design_omg  = [0.27 0.27 0.15];       % Omega vector in reference model
Control.Vessel.Ref.Design_ti   = [0.5 0.5 0.8];             % Time constants in surge, svai and yaw


% Design matrixes in reference model with respect to the paramterers set above

% Design matrix Af (with respect to time constants).
Control.Vessel.Ref.Matrix_Af =      [1/Control.Vessel.Ref.Design_ti(1) 0 0;         
                                    0 1/Control.Vessel.Ref.Design_ti(2) 0;          
                                    0 0 1/Control.Vessel.Ref.Design_ti(3)];

% Design Damp matrix in reference model (with respect to omega vector and relative damping).                                
Control.Vessel.Ref.Matrix_damp =    [2*Control.Vessel.Ref.Design_damp(1)*Control.Vessel.Ref.Design_omg(1) 0 0;     
                                    0 2*Control.Vessel.Ref.Design_damp(2)*Control.Vessel.Ref.Design_omg(2) 0;    
                                    0 0 2*Control.Vessel.Ref.Design_damp(3)*Control.Vessel.Ref.Design_omg(3)];

% Design spring force matrix in reference model (with respect to omega vector).                               
Control.Vessel.Ref.Matrix_spring =  [Control.Vessel.Ref.Design_omg(1)^2 0 0;                                   
                                    0 Control.Vessel.Ref.Design_omg(2)^2 0;                                       
                                    0 0 Control.Vessel.Ref.Design_omg(3)^2];
                                
% VELOCITY CONTROLLER
% -------------------------------------------------------------------------
    % Design parameters in reference model

Control.Vessel.Ref.Design_damp_vel = [0.96 0.96 0.97];                % Relative damping in reference model 
Control.Vessel.Ref.Design_omg_vel  = [0.27 0.27 0.25];   


Control.Vessel.Ref.Design_ti_vel   = [0.5 0.5 0.8];             % Time constants in surge, svai and yaw


% Design matrixes in reference model with respect to the paramterers set above

% Design matrix Af (with respect to time constants).
Control.Vessel.Ref.Matrix_Af_vel =      [1/Control.Vessel.Ref.Design_ti(1) 0 0;         
                                        0 1/Control.Vessel.Ref.Design_ti(2) 0;          
                                        0 0 1/Control.Vessel.Ref.Design_ti(3)];

% Design Damp matrix in reference model (with respect to omega vector and relative damping).                                
Control.Vessel.Ref.Matrix_damp_vel =    [2*Control.Vessel.Ref.Design_damp(1)*Control.Vessel.Ref.Design_omg(1) 0 0;     
                                        0 2*Control.Vessel.Ref.Design_damp(2)*Control.Vessel.Ref.Design_omg(2) 0;    
                                        0 0 2*Control.Vessel.Ref.Design_damp(3)*Control.Vessel.Ref.Design_omg(3)];                          



%************************************************************************************************************************************************************************
% Vessel observer settings, only used if Sim.Vessel_Obs == 1

%******************************													
% Wave data. Peak frequencies, damping ratio and filter cut-off frequency.  Assuming JONSWAP spectrum.
Control.VessObs.lmb   = 0.1;
Control.VessObs.omg_0 = Par.Wave.omega_peak;
Control.VessObs.damp  = 1;
Control.VessObs.omg_c = 5*Control.VessObs.omg_0; % In simulation
% Control.VessObs.omg_c = 2*Control.VessObs.omg_0; % In model tests

%******************************													
% Design parameters

Control.VessObs.Aw = [0 0 0 1 0 0; 
                      0 0 0 0 1 0; 
                      0 0 0 0 0 1; 
             -Control.VessObs.omg_0*Control.VessObs.omg_0 0 0 -2*Control.VessObs.lmb*Control.VessObs.omg_0 0 0; 
             0 -Control.VessObs.omg_0*Control.VessObs.omg_0 0 0 -2*Control.VessObs.lmb*Control.VessObs.omg_0 0; 
             0 0 -Control.VessObs.omg_0*Control.VessObs.omg_0 0 0 -2*Control.VessObs.lmb*Control.VessObs.omg_0];
   
Control.VessObs.Cw = [0 0 0 1 0 0; 
                      0 0 0 0 1 0; 
                      0 0 0 0 0 1];

Control.VessObs.T = [1000 0 0; 0 1000 0; 0 0 1000];
Control.VessObs.T_inv = inv(Control.VessObs.T);

%******************************													
% Inertia and damp matrix for 3DOF (Surge, sway and yaw)

Control.VessObs.M_inv = [Par.Vessel.M_inv(1,1) Par.Vessel.M_inv(1,2) Par.Vessel.M_inv(1,6);
                         Par.Vessel.M_inv(2,1) Par.Vessel.M_inv(2,2) Par.Vessel.M_inv(2,6);
                         Par.Vessel.M_inv(6,1) Par.Vessel.M_inv(6,2) Par.Vessel.M_inv(6,6)];
                     
Control.VessObs.D     = [Par.Vessel.DL(1,1) Par.Vessel.DL(1,2) Par.Vessel.DL(1,6);
                        Par.Vessel.DL(2,1) Par.Vessel.DL(2,2) Par.Vessel.DL(2,6);
                        Par.Vessel.DL(6,1) Par.Vessel.DL(6,2) Par.Vessel.DL(6,6)];

%******************************													
% Observer gain matrixes

Control.VessObs.K1 = [-2*(Control.VessObs.damp-Control.VessObs.lmb)*(Control.VessObs.omg_c/Control.VessObs.omg_0) 0 0; 
                      0 -2*(Control.VessObs.damp-Control.VessObs.lmb)*(Control.VessObs.omg_c/Control.VessObs.omg_0) 0; 
                      0 0 -2*(Control.VessObs.damp-Control.VessObs.lmb)*(Control.VessObs.omg_c/Control.VessObs.omg_0); 
                      2*Control.VessObs.omg_0*(Control.VessObs.damp-Control.VessObs.lmb) 0 0; 
                      0 2*Control.VessObs.omg_0*(Control.VessObs.damp-Control.VessObs.lmb) 0; 
                      0 0 2*Control.VessObs.omg_0*(Control.VessObs.damp-Control.VessObs.lmb)];

Control.VessObs.K2 = [Control.VessObs.omg_c 0 0; 
                       0 Control.VessObs.omg_c 0; 
                       0 0 Control.VessObs.omg_c];

Control.VessObs.K4 = [1000 0 0; 0 1000 0; 0 0 100];                     % Observergains for Cybership 3 In simulation
Control.VessObs.K3 = [100 0 0; 0 100 0; 0 0 10];
% Control.VessObs.K4 = [80 0 0; 0 80 0; 0 0 80];                          % Observergains for Cybership3 in model tests
% Control.VessObs.K3 = [10 0 0; 0 10 0; 0 0 10];
% 	
	
%-------------------------------------------------------------------------------------------------------------------------
% Calculations

% Nominal thruster characteristics
for thrno = 1:Sim.nthrusters

	Control.Thruster{thrno}.K_T0 = Par.Thruster{thrno}.K_T0;
	Control.Thruster{thrno}.K_Q0 = Par.Thruster{thrno}.K_Q0;

end

%******************************													
% Linear thruster characteristics, for use in estimation
for thrno = 1:Sim.nthrusters

	Control.Thruster{thrno}.Tww = Glob.rhow*Par.Thruster{thrno}.D^4*Par.Thruster{thrno}.a0/(4*pi^2);
	Control.Thruster{thrno}.Twv = Glob.rhow*Par.Thruster{thrno}.D^3*Par.Thruster{thrno}.a1/(2*pi);
	Control.Thruster{thrno}.Qww = Glob.rhow*Par.Thruster{thrno}.D^5*Par.Thruster{thrno}.b0/(4*pi^2);
	Control.Thruster{thrno}.Qwv = Glob.rhow*Par.Thruster{thrno}.D^4*Par.Thruster{thrno}.b1/(2*pi);

end

%******************************													
% Thrust allocation settings for NON-rotateable thrusters, Control.Alloc.Type = 2

% Clear old values
if isfield(Control.Alloc, 'T')
	Control.Alloc = rmfield(Control.Alloc,'T');
	Control.Alloc = rmfield(Control.Alloc,'W');
end

if  Control.Alloc.Type == 2 && length(find(Sim.Thruster_enable == 1)) < 3
	
	disp('No thrust allocation possible with so few thrusters')
	
end


% Return only zeros if less than 3 thrusters or if thrust allocation is not chosen. This is to avoid errors in Simulink
if length(find(Sim.Thruster_enable == 1)) < 3 || Sim.Thrust_alloc == 0
	
	Control.Alloc.T_inv = zeros(5,3);
	
else % Thrust allocation for the enabled thrusters
	
	ccc = 0;
	for cc = 1:Sim.nthrusters
		
		if Sim.Thruster_enable(cc) == 1 % Using only the enabled thrusters
			ccc = ccc + 1;
			
			% Standard thrust configuration matrix
			cos_a 	= cos(Par.Thruster{ccc}.alpha);
			sin_a 	= sin(Par.Thruster{ccc}.alpha);
			x_t 	= Par.Thruster{ccc}.r_p(1);
			y_t 	= Par.Thruster{ccc}.r_p(2);
			Control.Alloc.T(:,ccc) = [cos_a; sin_a; -cos_a*y_t + sin_a*x_t]; 
			
			% Thrust allocation weight matrix
			Control.Alloc.W(ccc,ccc) = Par.Thruster{ccc}.control_weight;
			
		end
		
	end
	
	% Generalized Inverse
	Control.Alloc.T_inv = inv(Control.Alloc.W)*Control.Alloc.T'*inv(Control.Alloc.T*inv(Control.Alloc.W)*Control.Alloc.T');
	
	% Insert zeros for the disabled thrusters
	for cc = 1:Sim.nthrusters
		
		if Sim.Thruster_enable(cc) == 0 % Disabled thruster
			
			% Shift all entries below this thruster down one index
			for dd = ccc:-1:cc
				Control.Alloc.T_inv(dd+1,:) = Control.Alloc.T_inv(dd,:);
			end
			
			ccc = ccc + 1;
			
			% Insert zeros
			Control.Alloc.T_inv(cc,:) = [0 0 0];
			
		end
		
	end
	
end


%**************************************************************************************************************************													
% Thrust allocation settings for ROTATEABLE THRUSTERS,Control.Alloc.Type = 3
% Author: Kjell Erik Larsen: Kjell.Erik.Larsen@gmail.com, 2012
Allocation;             %User Specified Control Allocation



 


