function s_omega = PM_Spectrum(Par_Wave, omega)
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
%
% PM_Spectrum(Par_Wave, omega)
%
% Project:	"Marine Cybernetics Simulator: MCsim"
%
% Abstract:	Calculate PM spectrum values by ISSC/ITTC standard
% 
% Inputs:	Wave				- Structure containing wave parameters:
%			Wave.omega_mean		- Mean frequency in spectrum
%			Wave.hs				- Significant wave heigth in sea state
%
% Outputs:	s_omega				- Spectrum value
%	
% Calls:	-
%
% Author:	yvind Smogeli, Autumn 2001
%
% Changes:	OS, Autumn 2002: Changed structure naming for MCSim
%			OS, Spring 2003: Changed spectrum parameters from 0.11 and 0.44 to 0.31 and 1.25
%							 This corresponds to using PEAK frequency instead of mean frequency
%
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
 		

hs 			= Par_Wave.hs;			% Significant wave height
omega_mean	= Par_Wave.omega_mean;	% Peak frequency in spectrum

% PM constants
a = 0.31*hs^2*omega_mean^4;
b = 1.25*omega_mean^4;

% Spectrum value
s_omega = a/omega^5*exp(-b/omega^4);

