function Par_Thruster = Thruster_config
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
% Par_Thruster = Thruster_config
%
% Project:	"Marine Cybernetics Simulator: MCSim"
%
% Abstract:	Loads thruster data	for simulation, defines the thruster positions and
%			orientations. As many thrusters as defined in the Simulink MCSim file
%			must be initialized. If not all are used, disable them in the Parameters.m
%			file.
% 
% Inputs:	- 
%
% Outputs:	Par.Thruster
%
% Calls:	Thruster_data
%						
% Author:	Oyvind Smogeli, Summer 2003
%
% Revision:	-
%
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 

% Load all thruster defintions into structure "Thrusters"
global Glob
Thruster_data;

% Define the thrusters
% Thruster types:
% 1 - Ducted main prop, 4 quadrant data
% 2 - Unducted main prop, 4 quadrant data
% 3 - Unducted main prop, 1-quadrant data
% 4 - Unducted main prop, nominal data (only KT0 and KQ0, no Va dependence)
% 5 - Tunnel thruster, bow mounted
% 6 - CPP propeller, no pitch control implemented yet


% Thruster 3 - Tunnel Thruster: However the real tunnel thruster is not working, using the Bau Azimuth as a tunnel thruster.
% Tunnel thruster, use always positive y-coordinate for defining half breadth of vessel at thruster
Par_Thruster{1}			= Thrusters{1};		% Tunnel thruster
Par_Thruster{1}.r_p		= [0.55 0 0]';		% thruster position(x,y,z)
Par_Thruster{1}.alpha	= pi/2;				% thruster orientation
Par_Thruster{1}.fixed_dir = 1;              % Fixed direction as tunnel thruster
%New Thruster coefficients for Cybership III; added by Kjell Erik Larsen
Par_Thruster{1}.D		= 0.04;
Par_Thruster{1}.Ktp = [-0.1389; -0.4250; 0.6016];
Par_Thruster{1}.RPM_p_max = 4800;
Par_Thruster{1}.RPM_p_T		= 0.1;			
Par_Thruster{1}.RPM_p_rate	= 0.2*4800; % Max propeller rate 


% Thruster 2 - starBoard main propeller
Par_Thruster{2}             = Thrusters{3};		% Ducted main prop
Par_Thruster{2}.r_p         = [-0.875 0.12 0]';		% thruster position(x,y,z)
Par_Thruster{2}.alpha       = 15*pi/180;				% thruster orientation
Par_Thruster{2}.fixed_dir   = 1;
%New Thruster coefficients for Cybership III; added by Kjell Erik Larsen
Par_Thruster{2}.D           = 0.09;
Par_Thruster{2}.Ktp         = [-0.0475; -0.1452; 0.2056];
Par_Thruster{2}.RPM_p_max   = 2400;
Par_Thruster{2}.RPM_p_T		= 0.1;			
Par_Thruster{2}.RPM_p_rate	= 0.2*2400; % Max propeller rate 

% Thruster 3 - port main propeller
Par_Thruster{3}             = Thrusters{3};		% Ducted main prop
Par_Thruster{3}.r_p         = [-0.875 -0.12 0]';	% thruster position(x,y,z)
Par_Thruster{3}.alpha       = -Par_Thruster{2}.alpha;				% thruster orientation
Par_Thruster{3}.fixed_dir   = 1;
%New Thruster coefficients for Cybership III; added by Kjell Erik Larsen
Par_Thruster{3}.D           = 0.09;
Par_Thruster{3}.Ktp         = [-0.0475; -0.1452; 0.2056];
Par_Thruster{3}.RPM_p_max   = 2400;
Par_Thruster{3}.RPM_p_T		= 0.1;
Par_Thruster{3}.RPM_p_rate	= 0.2*2400; % Max propeller rate 

%% Non Used Trusters
% Thruster 4
Par_Thruster{4} 		= Par_Thruster{3};
% Thruster 5
Par_Thruster{5} 		= Par_Thruster{3};

