%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
%
% CS3_init.m
%
% Project:	Development of DP system for Cybership 3
%
% Abstract:	Setting up parameters for DP with Cybership 3
% 
% Inputs:	-
%
% Outputs:	-
%	
% Calls:	-
%
% Author:	Martin Austad, spring 2004
%
% Changes:	..
%
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 

%-----------------------------------------------------------------------------------------
% Main particulars for CS3
%-----------------------------------------------------------------------------------------

Par_Vessel.l			= 1.971; 				% lpp (m)
Par_Vessel.b			= 0.437;				% breadth (m)
Par_Vessel.t			= 0.153;				% draft (m)
Par_Vessel.dpl			= 0.075;	            % displacement (m^3)
Par_Vessel.gmt			= 0.02;				    % transverse metacentric height (m)
Par_Vessel.gml 			= 1.474;				% longship metacentric height (m)
Par_Vessel.awp			= 0.656;				% waterplane area (m^2)
Par_Vessel.rgyr_x		= 0.1713;				% radius of gyration, roll (m) 
Par_Vessel.rgyr_y		= 0.5138;				% radius of gyration, pitch (m) 
Par_Vessel.rgyr_z		= 0.5138;				% radius of gyration, yaw (m)
Par_Vessel.wind_area_x 	= 0.0677;				% projected wind force area, surge (m^2) (rough estimate)
Par_Vessel.wind_area_y 	= 0.4;				    % projected wind force area, sway (m^2) (rough estimate)
Par_Vessel.curr_area_x 	= 0.0620;				% projected current force area, surge (m^2)
Par_Vessel.curr_area_y 	= 0.25;				    % projected current force area, sway (m^2)

%Lines 49-59 accepted, but not verified

Par_Vessel.wd_arm_x		= Par_Vessel.t/2;	% arm for estimating pitch wavedrift from surge (m)
Par_Vessel.wd_arm_y		= Par_Vessel.t/2;	% arm for estimating roll wavedrift from sway (m)

Par_Vessel.curr_arm_x	= Par_Vessel.t/2;	% arm for estimating pitch current response from surge (m)
Par_Vessel.curr_arm_y	= Par_Vessel.t/2;	% arm for estimating roll current response from sway (m)

% This is a rough estimate, we should know the exact superstructure area distribution
Par_Vessel.wind_arm_x	= Par_Vessel.wind_area_x/Par_Vessel.b/2;	% arm for estimating pitch wind response from surge (m)
Par_Vessel.wind_arm_y	= Par_Vessel.wind_area_y/Par_Vessel.l/2;	% arm for estimating roll wind response from sway (m)


% Global constants
Glob.g 					= 9.81;			% Constant of gravity
Glob.rhow				= 1025;			% Density of seawater
Glob.p_0				= 101325;		% Atmospheric pressure
Glob.p_w				= 1230;			% Evaporation pressure of water
Glob.epsilon			= 1E-3;			% Small number

% Model reduction matrix
Glob.H36 = [1 0 0 0 0 0; 0 1 0 0 0 0 ; 0 0 0 0 0 1];

Par_Vessel.mass			= Par_Vessel.dpl*Glob.rhow;		% dry mass (kg)

%-----------------------------------------------------------------------------------------
% Coordinates - 
%-----------------------------------------------------------------------------------------
% All vectors defined with respect to the hydrodynamic center coh, which is defined in:
% Ship:		At lpp/2 and in the waterplane
% Platform:	?

Par_Vessel.r_cg 		= [0.036 0 -0.043];	% vector from coh to center of gravity
Par_Vessel.r_cb 		= [0.036 0 0.065];	% vector from coh to center of bouyancy
Par_Vessel.r_ca 		= [0 0 0];			% vector from coh to center of added mass
Par_Vessel.r_cd 		= [0.036 0 -0.043];	% vector from coh to center of damping

%-----------------------------------------------------------------------------------------
% Rigid-body inertia matrix
%-----------------------------------------------------------------------------------------

% Rigid-body mass
m0		= Par_Vessel.mass;

% Moments of inertia
i_x		= Par_Vessel.mass*Par_Vessel.rgyr_x^2;     
i_y		= Par_Vessel.mass*Par_Vessel.rgyr_y^2;     
i_z		= Par_Vessel.mass*Par_Vessel.rgyr_z^2;     
i_xy	= 0;                                
i_xz 	= 0;
i_yz 	= 0;

I0 = [ ...
	 i_x  -i_xy -i_xz
	-i_xz  i_y  -i_yz
	-i_xz -i_yz  i_z ];
        
% Inertia matrix about CG 
Par_Vessel.M_rb_CG = [...
	m0*eye(3,3)	, zeros(3,3);
	zeros(3,3)	, I0		];
	
% Transformed to COH	
Par_Vessel.M_rb = Hmtrx(Par_Vessel.r_cg)'*Par_Vessel.M_rb_CG*Hmtrx(Par_Vessel.r_cg);

%-----------------------------------------------------------------------------------------
% Added mass matrix - From VERES
%-----------------------------------------------------------------------------------------

%CA(1,1) based on Fossen 2002, p. 313, may very well be used incorrectly!


% About CA
Par_Vessel.M_a_CA = [0.006E+00   0.000E+00   0.000E+00   0.000E+00   0.000E+00   0.000E+00
          0.000E+00   0.727E+02   0.000E+00   -.274E+01   0.000E+00   -.384E+01
          0.000E+00   0.000E+00   0.160E+03   0.000E+00   -.590E+01   0.000E+00
          0.000E+00   -.274E+01   0.000E+00   0.433E+00   0.000E+00   -.322E+00
          0.000E+00   0.000E+00   -.590E+01   0.000E+00   0.279E+02   0.000E+00
          0.000E+00   -.384E+01   0.000E+00   -.322E+00   0.000E+00   0.137E+02];

% Transformed to COH	
Par_Vessel.M_a = Hmtrx(Par_Vessel.r_ca)'*Par_Vessel.M_a_CA*Hmtrx(Par_Vessel.r_ca);
		
%-----------------------------------------------------------------------------------------
% Generalized inertia matrix M 
%-----------------------------------------------------------------------------------------
		
% Add M and M0 and A0 in COH
Par_Vessel.M = Par_Vessel.M_rb + Par_Vessel.M_a;
	
% Inverted
Par_Vessel.M_inv = inv(Par_Vessel.M);


%-----------------------------------------------------------------------------------------
% Linear damping with respect to COH - from VERES
%-----------------------------------------------------------------------------------------

Par_Vessel.DL_CD = [0.000E+00   0.000E+00   0.000E+00   0.000E+00   0.000E+00   0.000E+00
          0.000E+00   0.132E+02   0.000E+00   -.663E+00   0.000E+00   0.110E+00
          0.000E+00   0.000E+00   0.453E+03   0.000E+00   -.125E+02   0.000E+00
          0.000E+00   -.663E+00   0.000E+00   0.386E-01   0.000E+00   -.643E-01
          0.000E+00   0.000E+00   -.125E+02   0.000E+00   0.796E+02   0.000E+00
          0.000E+00   0.110E+00   0.000E+00   -.643E-01   0.000E+00   0.189E+01];

% Transform to COH 
Par_Vessel.DL = Hmtrx(Par_Vessel.r_cd)'*Par_Vessel.DL_CD*Hmtrx(Par_Vessel.r_cd);
		

%Calculations based on Fossen 2002, p. 313
% Time constants for linear damping
Par_Vessel.T_surge = 6.3;
Par_Vessel.T_sway = 12.6;
Par_Vessel.T_yaw = 7.8;

% Linear damping from time constants and generalized mass
d11 = Par_Vessel.M(1,1)/Par_Vessel.T_surge;
d22 = Par_Vessel.M(2,2)/Par_Vessel.T_sway;
d66 = Par_Vessel.M(6,6)/Par_Vessel.T_yaw;

% Substitute with the time constant values.
% Check => Of the same order of magnitude, OK
Par_Vessel.DL(1,1)	= d11;
Par_Vessel.DL(2,2)	= d22;
Par_Vessel.DL(6,6)	= d66;


%**************************************************************************
% VESSEL CONTROLLER SETTINGS
%**************************************************************************
												
% PID DP settings
Control.PID.zeta				= [2 2 2];	        % Design damping ratio [-] [surge sway yaw]
Control.PID.T_n					= [15 15 20];	    % Design time constant [s] [surge sway yaw]
Control.PID.K_m					= [0 0 0];		    % Acceleration feedback constants [surge sway yaw]
Control.PID.T_i_fac				= [10 10 10];	    % Factor by which the integral time constant is slower than the natural frequency

Control.Tau_max					= [1.5 1.5 9];	% Max thrust vector

Control.PID.Ki_sat				= 0.8*Control.Tau_max;	% Saturation of integral term

Control.PID.M					= diag(Glob.H36*Par_Vessel.M*Glob.H36')';	% 3DOF mass matrix main diagonal values from vessel model
Control.PID.D					= diag(Glob.H36*Par_Vessel.DL*Glob.H36')';	% 3DOF linear damping matrix main diagonal values from vessel model

% Controller design
Control.PID.omega_n				= 2*pi./Control.PID.T_n;
Control.PID.Kp					= (Control.PID.M + Control.PID.K_m).*Control.PID.omega_n.^2;									% Proportional gain vector
Control.PID.Kd					= (Control.PID.M + Control.PID.K_m)*2.*Control.PID.zeta.*Control.PID.omega_n - Control.PID.D;	% Derivative gain vector
Control.PID.Ki					= Control.PID.omega_n.*Control.PID.Kp./Control.PID.T_i_fac;										% Integral gain vector

												
% Horizontal-plane DP settings

    % Model reference feedforward control action:

Control.Vessel_3_DOF.M =     [Par_Vessel.M(1,1) Par_Vessel.M(1,2) Par_Vessel.M(1,6);
                              Par_Vessel.M(2,1) Par_Vessel.M(2,2) Par_Vessel.M(2,6);
                              Par_Vessel.M(6,1) Par_Vessel.M(6,2) Par_Vessel.M(6,6)];
 
Control.Vessel_3_DOF.D =     [Par_Vessel.DL(1,1) Par_Vessel.DL(1,2) Par_Vessel.DL(1,6);
                              Par_Vessel.DL(2,1) Par_Vessel.DL(2,2) Par_Vessel.DL(2,6);
                              Par_Vessel.DL(6,1) Par_Vessel.DL(6,2) Par_Vessel.DL(6,6)];
                          

    % PD-control action: (Method as described in Fossen (2002)).

Control.Vessel_3_DOF.M_vect = [Control.Vessel_3_DOF.M(1,1) Control.Vessel_3_DOF.M(2,2) Control.Vessel_3_DOF.M(3,3)];
Control.Vessel_3_DOF.D_vect = [Control.Vessel_3_DOF.D(1,1) Control.Vessel_3_DOF.D(2,2) Control.Vessel_3_DOF.D(3,3)];

% Design parameters, used for determination of PD-gains.
Control.Vessel.PID.T     =  [93.67 142.3 82.4];   			% Design time constants in surge, sway and yaw
Control.Vessel.PID.omg_n =  2*pi./Control.Vessel.PID.T; % Natural frequency in surge, sway and yaw
Control.Vessel.PID.zeta  =  [1.58 1.66 1.09]; 			% Design damping ratio in surge, sway and yaw
Control.Vessel.PID.Ifact =  [3.41 1.98 25.2];  			% Factor by which the time integral is slower than the natural frequency

% PD-GAINS:

    % Proportional Gain
Control.Vessel.P_Gain.Gp = Control.Vessel_3_DOF.M_vect.*Control.Vessel.PID.omg_n.^2;          

    % Derivate Gain
Control.Vessel.D_Gain.Gd = 2.*Control.Vessel.PID.zeta.*Control.Vessel.PID.omg_n.*Control.Vessel_3_DOF.M_vect-Control.Vessel_3_DOF.D_vect;                                     


% INTEGRAL ACTION
Control.Vessel.Int.antiwindup.A_w = [0 0 0; 0 0 0; 0 0 0];       % Anti-windup precaution matrix

    % Integrator gain matrix
    
Control.Vessel.I_Gain.Gi = (-1).*Control.Vessel.PID.omg_n.*Control.Vessel.P_Gain.Gp./Control.Vessel.PID.Ifact; 

% #########################################################################
% REFERENCE MODEL SETTINGS
% #########################################################################

Control.Vessel.max_vel_d = [0.15 0.15 0.15];           % Sets desired maximum velocity for vessel in surge, svai and yaw
Control.Vessel.max_acc_d = [0.04 0.04 0.04];           % Sets desired maximum acceleration for vessel in surge, svai and yaw

% POSITION CONTROLLER
% -------------------------------------------------------------------------
    

    % Design parameters in reference model
Control.Vessel.Ref.Design_damp = [0.96 0.96 0.97];                % Relative damping in reference model 
Control.Vessel.Ref.Design_omg  = [0.27 0.27 0.15];   
Control.Vessel.Ref.Design_ti   = [0.5 0.5 0.8];             % Time constants in surge, svai and yaw


    % Design matrixes in reference model with respect to the paramterers set above

    % Design matrix Af (with respect to time constants).
Control.Vessel.Ref.Matrix_Af =      [1/Control.Vessel.Ref.Design_ti(1) 0 0;         
                                    0 1/Control.Vessel.Ref.Design_ti(2) 0;          
                                    0 0 1/Control.Vessel.Ref.Design_ti(3)];

    % Design Damp matrix in reference model (with respect to omega vector and relative damping).                                
Control.Vessel.Ref.Matrix_damp =    [2*Control.Vessel.Ref.Design_damp(1)*Control.Vessel.Ref.Design_omg(1) 0 0;     
                                    0 2*Control.Vessel.Ref.Design_damp(2)*Control.Vessel.Ref.Design_omg(2) 0;    
                                    0 0 2*Control.Vessel.Ref.Design_damp(3)*Control.Vessel.Ref.Design_omg(3)];

    % Design spring force matrix in reference model (with respect to omega vector).                               
Control.Vessel.Ref.Matrix_spring =  [Control.Vessel.Ref.Design_omg(1)^2 0 0;                                   
                                    0 Control.Vessel.Ref.Design_omg(2)^2 0;                                       
                                    0 0 Control.Vessel.Ref.Design_omg(3)^2];
                                
% VELOCITY CONTROLLER
% -------------------------------------------------------------------------
    % Design parameters in reference model

Control.Vessel.Ref.Design_damp_vel = [0.96 0.96 0.97];                % Relative damping in reference model 
Control.Vessel.Ref.Design_omg_vel  = [0.27 0.27 0.25];   


Control.Vessel.Ref.Design_ti_vel   = [0.5 0.5 0.8];             % Time constants in surge, svai and yaw


% Design matrixes in reference model with respect to the paramterers set above

% Design matrix Af (with respect to time constants).
Control.Vessel.Ref.Matrix_Af_vel =      [1/Control.Vessel.Ref.Design_ti(1) 0 0;         
                                        0 1/Control.Vessel.Ref.Design_ti(2) 0;          
                                        0 0 1/Control.Vessel.Ref.Design_ti(3)];

% Design Damp matrix in reference model (with respect to omega vector and relative damping).                                
Control.Vessel.Ref.Matrix_damp_vel =    [2*Control.Vessel.Ref.Design_damp(1)*Control.Vessel.Ref.Design_omg(1) 0 0;     
                                        0 2*Control.Vessel.Ref.Design_damp(2)*Control.Vessel.Ref.Design_omg(2) 0;    
                                        0 0 2*Control.Vessel.Ref.Design_damp(3)*Control.Vessel.Ref.Design_omg(3)];                          



%**************************************************************************
% VESSEL OBSERVER SETTINGS
%**************************************************************************

% Wave data. Peak frequencies, damping ratio and filter cut-off frequency.  Assuming JONSWAP spectrum.
Control.VessObs.lmb   = 0.1;
Control.VessObs.omg_0 = 3;
Control.VessObs.damp  = 1;
Control.VessObs.omg_c = 2*Control.VessObs.omg_0;

% Design parameters

Control.VessObs.Aw = [0 0 0 1 0 0; 
                      0 0 0 0 1 0; 
                      0 0 0 0 0 1; 
             -Control.VessObs.omg_0*Control.VessObs.omg_0 0 0 -2*Control.VessObs.lmb*Control.VessObs.omg_0 0 0; 
             0 -Control.VessObs.omg_0*Control.VessObs.omg_0 0 0 -2*Control.VessObs.lmb*Control.VessObs.omg_0 0; 
             0 0 -Control.VessObs.omg_0*Control.VessObs.omg_0 0 0 -2*Control.VessObs.lmb*Control.VessObs.omg_0];
   
Control.VessObs.Cw = [0 0 0 1 0 0; 
                      0 0 0 0 1 0; 
                      0 0 0 0 0 1];

% Inertia and damp matrix for 3DOF (Surge, sway and yaw)

Control.VessObs.M_inv = [Par_Vessel.M_inv(1,1) Par_Vessel.M_inv(1,2) Par_Vessel.M_inv(1,6);
                         Par_Vessel.M_inv(2,1) Par_Vessel.M_inv(2,2) Par_Vessel.M_inv(2,6);
                         Par_Vessel.M_inv(6,1) Par_Vessel.M_inv(6,2) Par_Vessel.M_inv(6,6)];
                     
Control.VessObs.D     = [Par_Vessel.DL(1,1) Par_Vessel.DL(1,2) Par_Vessel.DL(1,6);
                        Par_Vessel.DL(2,1) Par_Vessel.DL(2,2) Par_Vessel.DL(2,6);
                        Par_Vessel.DL(6,1) Par_Vessel.DL(6,2) Par_Vessel.DL(6,6)];
                    
% Observer gain matrixes

Control.VessObs.K1 = [-2*(Control.VessObs.damp-Control.VessObs.lmb)*(Control.VessObs.omg_c/Control.VessObs.omg_0) 0 0; 
                      0 -2*(Control.VessObs.damp-Control.VessObs.lmb)*(Control.VessObs.omg_c/Control.VessObs.omg_0) 0; 
                      0 0 -2*(Control.VessObs.damp-Control.VessObs.lmb)*(Control.VessObs.omg_c/Control.VessObs.omg_0); 
                      2*Control.VessObs.omg_0*(Control.VessObs.damp-Control.VessObs.lmb) 0 0; 
                      0 2*Control.VessObs.omg_0*(Control.VessObs.damp-Control.VessObs.lmb) 0; 
                      0 0 2*Control.VessObs.omg_0*(Control.VessObs.damp-Control.VessObs.lmb)];

Control.VessObs.K2 = [Control.VessObs.omg_c 0 0; 
                       0 Control.VessObs.omg_c 0; 
                       0 0 Control.VessObs.omg_c];

Control.VessObs.K4 = [80 0 0; 0 80 0; 0 0 80];                   % Observergains for Cybership 3, testset#1
Control.VessObs.K3 = [10 0 0; 0 10 0; 0 0 10];                   