function [Par_Wave, Par_Wind] = Exp_environ(Par_Wave, Par_Wind, Par_Vessel_wind_arm_y)
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
%
% [Par.Wave, Par.Wind] = Exp_environ(Par.Wave, Par.Wind, Par.Vessel.wind_arm_y)
%
% Project:	"Marine Cybernetics Simulator: MCSim"
%
% Abstract:	Calculate expectation values based on Hs if desired, define wind x and y components
% 
% Inputs:	Par.Wave, Par.Wind, Par.Vessel.wind_arm_y
%
% Outputs:	Par.Wave, Par.Wind
%	
% Calls:	-
%
% Author:	yvind Smogeli, Summer 2003
%
% Changes:	-
%
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 

% Peak frequency component in sea state, expectation value based on Hs if not specified by user
if Par_Wave.omega_peak <= 0
    Par_Wave.omega_peak		= 2*pi/(4.883+2.68*Par_Wave.hs^0.54);
	disp(' ')
	disp(sprintf('Calculated peak wave frequency: %0.2f rad/s',Par_Wave.omega_peak))
end

% Mean wind speed and direction based on Hs and mean wave direction if not specified by user
if Par_Wind.u10 == -1
	Par_Wind.u10 = 1.764 + 3.426*Par_Wave.hs^0.78; % Mean wind speed at 10 meters
	Par_Wind.dir = Par_Wave.psi_mean;
	disp(' ')
	disp(sprintf('Calculated mean wind velocity at 10 meters (u10):  %0.2f m/s',Par_Wind.u10))
	disp(sprintf('Calculated mean wind direction: %0.0f degrees',Par_Wind.dir*180/pi))	
end

% Wind velocity at mean superstructure height (Par_Vessel.wind_arm_y)
z0 = 10*exp(-2/(5*sqrt(Par_Wind.kappa)));
Par_Wind.vel = Par_Wind.u10*5/2*sqrt(Par_Wind.kappa)*log(Par_Vessel_wind_arm_y/z0); 

