function Ia = Thr_add_mass(Par_Thruster)
% Added mass calculation
% Formula by Parsons and Vorus for Wageningen B-series 4-bladed propellers

global Glob
rhow = Glob.rhow;

% Prop data
EAR	= Par_Thruster.EAR;
PD	= Par_Thruster.PD;
D	= Par_Thruster.D;
Z	= Par_Thruster.Z;
AR	= 0.22087*Z/EAR;

if Z ~= 4

	disp(sprintf('Warning: Z = %g, calculation only applicable for Z = 4', Z))
	
end

P	= [1 EAR PD EAR^2 PD^2 EAR*PD]';
P2	= [1 PD AR^(-1) AR^(-2) PD*AR^(-1) PD*AR^(-2)]';

% Coefs
C	= [0.30315E-2 -0.80782E-2 -0.40731E-2 0.34170E-2 0.43437E-3 0.99715E-2];
C2	= [0.61046 0.34674 0.60294 -0.56159 -0.80696 0.45806];

% Lifting line estimate
Ia0	= C*P*rhow*D^5;

% Lifting surface correction
LSC	= C2*P2;
Ia	= Ia0*LSC;