function Par_Wind = Wind_spectrum(Par_Wind, Par_Vessel_wind_arm_y)
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
%
% Par.Wind = Wind_spectrum(Par.Wind, Par.Vessel.wind_arm_y)
%
% Project:	"Marine Cybernetics Simulator: MCSim"
%
% Abstract:	Calculate Harris or NORSOK wind spectrum
% 
% Inputs:	Par.Wind				- Structure containing wind parameters
%			Par.Vessel.wind_arm_y	- Height of wind force point of attack
%
% Outputs:	Par.Wind				- Updated with new wind parameters
%	
% Calls:	-
%
% Author:	yvind Smogeli, Summer 2003
%
% Changes:	-
%
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 

spec	= Par_Wind.spectrum;		% 1 for Harris wind spectrum, 2 for NORSOK wind spectrum
u10		= Par_Wind.u10;				% 1 hour mean wind velocity at 10 meters
kappa	= Par_Wind.kappa_H;			% Sea surface drag coefficient Harris wind spectrum
L		= Par_Wind.L;				% Scaling length for Harris wind spectrum
n		= Par_Wind.n;				% NORSOK spectrum parameter
z		= Par_Vessel_wind_arm_y;	% Wind force center height
nfreq	= Par_Wind.nfreq;			% Number of frequency components in gust realization
minfreq	= Par_Wind.minfreq;			% Minimum frequency in gust realization [Hz]
maxfreq = Par_Wind.maxfreq;			% Maximum frequency in gust realization [Hz]

dfreq = (maxfreq-minfreq)/nfreq;
freqs = minfreq:dfreq:maxfreq;

if spec == 1 | spec == 2
	
	k = 0;
	
	for f = freqs
		
		k = k + 1;
		
		if spec == 1
		
			ff = L*f/u10;
			S = 4*kappa*L*u10/(2+ff^2)^(5/6); % Spectrum value
			
		else
			
			x = 172*f*(z/10)^(2/3)*(u10/10)^(-3/4);
			S = 320*(u10/10)^2*(z/10)^0.45/(1+x^n)^(5/(3*n)); % Spectrum value
			
		end
			
		Amp(k) = sqrt(2*S*dfreq); % Gust amplitude
				
	end	
	
	Par_Wind.Omega = freqs*2*pi;	% Circular frequency
	Par_Wind.Amp = Amp;
	Par_Wind.Phase = rand(1,k)*2*pi; % Random phase angles
	

else

		disp('Invalid value of Par.Wind.spectrum, gust set to zero')
		Par_Wind.gust = 0;
	
end
