close all;
totalSteps = Sim.SimulationTime/stepLength;
% Rename the parameters before running QpSolver to Matlab
    T_qpOASES = simout_T;
    T_delta_qpOASES = simout_delta_T;
    Alpha_qpOASES = simout_alpha;
    Alpha_delta_qpOASES = simout_delta_alpha;
    s_qpOASES = simout_x(:,(1+nc):nx);
    time_qpOASES = (0:stepLength:Sim.SimulationTime);
    x_qpOASES = simout_x;
    x_raw_qpOASES = simout_x_raw;
    status_qpOASES = simout_status;
    nWSR_qpOASES = simout_nWSR;
    
    %Commanded Forces
    tau_c_qpOASES = simout_tau_c;

    % Matrices renaming
    A_qpOASES = simout_A;
    H_qpOASES = simout_H;
    g_qpOASES = simout_g;
    lbA_qpOASES = simout_lbA;
    ubA_qpOASES = simout_ubA;
    lbX_qpOASES = simout_lbX;
    ubX_qpOASES = simout_ubX;
    B_alphaPrev_qpOASES = simout_B_alphaPrev;
    B_Jacobian_qpOASES = simout_B_Jacobian;
    
    %Cost Function
    J_qpOASES = simout_costFunction;
   
    diffqpOASESandTauc = zeros(totalSteps,nt);
    diffqpOASESandTaucWithS = zeros(totalSteps,nt);
    diffqpOASESandTaucWithSLinearized =  zeros(totalSteps,nt);
    diffqpOASESCostFunction =  zeros(totalSteps, 1);
    for i = 1:1:totalSteps+1
        diffqpOASESandTauc(i,:) = (B_matrix(Alpha_qpOASES(:,:,i), lx, ly)*T_qpOASES(:,:,i)')' - tau_c_qpOASES(i,:);
        %(B_alphaPrev_qpOASES(:,:,i)*T_qpOASES(:,:,i)')' + (B_Jacobian_qpOASES(:,:,i)*Alpha_delta_qpOASES(:,:,i)')' - tau_c_qpOASES(:,:,i);
        diffqpOASESandTaucWithS(i,:) = (B_matrix(Alpha_qpOASES(:,:,i), lx, ly)*T_qpOASES(:,:,i)')' +  s_qpOASES(i,:) - tau_c_qpOASES(i,:);
        %(B_alphaPrev_qpOASES(:,:,i)*T_qpOASES(:,:,i)')' + s_qpOASES(i,:) - tau_c_qpOASES(:,:,i);
        diffqpOASESandTaucWithSLinearized(i,:) = (A_qpOASES(1:nt,:,i)*[T_qpOASES(:,:,i)'; Alpha_delta_qpOASES(:,:,i)'; s_qpOASES(i,:)'])' - tau_c_qpOASES(i,:);
        %(B_alphaPrev_qpOASES(:,:,i)*T_qpOASES(:,:,i)')' + (B_Jacobian_qpOASES(:,:,i)*Alpha_delta_qpOASES(:,:,i)')' + s_qpOASES(i,:) - tau_c_qpOASES(:,:,i);
        temp = [T_delta_qpOASES(:,:,i)';Alpha_delta_qpOASES(:,:,i)';s_qpOASES(i,:)'];
        diffqpOASESCostFunction(i,1) = 0.5*(temp'*H_qpOASES(:,:,i)*temp)-J_qpOASES(i);
    end
    
    disp( ' Maximum Error Between qpOASES and tau_c:  diffqpOASESandTauc ');
    disp(max(max(abs(diffqpOASESandTauc))));
    disp( ' Maximum Error Between qpOASES and tau_c including s: diffqpOASESandTaucWithS ');
    disp(max(max(abs(diffqpOASESandTaucWithS))));
    disp( ' Maximum Error Between qpOASES and tau_c including s Linearized function: diffqpOASESandTaucWithSLinearized ');
    disp(max(max(abs(diffqpOASESandTaucWithSLinearized))));
    disp( ' Maximum Difference between calculated cost function and output from qpOASES algorithm: diffqpOASESCostFunction ');
    disp(max(max(abs(diffqpOASESCostFunction))));
    
    if (max(max(abs(diffqpOASESandTaucWithSLinearized))) < -1e-9 || max(max(abs(diffqpOASESandTaucWithSLinearized))) > 1e-9)
        disp('#################### An Infeasible solution was found, check diffqpOASESandTaucWithS for information ############################');
    end
    disp(' ----------------------------------------------------------- ');

%% QpOASES
    tau_c_plot_qpOASES = zeros(totalSteps,nt);
    T_qpOASES_plot = zeros(totalSteps, nt);
    Alpha_qpOASES_plot = zeros(totalSteps, na);
    for i = 1:1:totalSteps+1
        tau_c_plot_qpOASES(i,:) = tau_c_qpOASES(i,:);
        T_qpOASES_plot(i,:) = T_qpOASES(:,:,i);
        Alpha_qpOASES_plot(i,:) = Alpha_qpOASES(:,:,i);
    end

    %QpOASES
    figure('name','tau_c_plot_qpOASES');
    hold on;
    grid on;
    plot((0:stepLength:Sim.SimulationTime), tau_c_plot_qpOASES(:,1),'k');
    plot((0:stepLength:Sim.SimulationTime), tau_c_plot_qpOASES(:,2),'b');
    plot((0:stepLength:Sim.SimulationTime), tau_c_plot_qpOASES(:,3),'r');
    hold off;
    xlabel('Time [s]');
    ylabel('tau_c plot-qpOASES');
    legend('X','Y','N');
    title('tau_c_plot_qpOASES Input');
    hold off;

    %Thrust
    figure('name','Thrust setpoint for thrusters: qpOASES');
    hold on;
    grid on;
    for i=1:nt
        s = cell(1, size(nt,1));
        subplot(3,1,i)
        plot((0:stepLength:Sim.SimulationTime), T_qpOASES_plot(:,i),'k', ...
            (0:stepLength:Sim.SimulationTime), (T_max(i).*ones(1,length((0:stepLength:Sim.SimulationTime)))), ...
            (0:stepLength:Sim.SimulationTime), (T_min(i).*ones(1,length((0:stepLength:Sim.SimulationTime)))));
        set(0,'DefaultAxesColorOrder',[1 0 0],...
            'DefaultAxesLineStyleOrder','-|--|:|-.', 'defaultlinelinewidth',2)
        xlabel('Time [s]');
        ylabel('Thrust setpint in [N]');
        legend('T_d', 'T_{max}', 'T_{min}');
        xmin = T_min(i)-10;
        xmax = T_max(i)+10;
        ymin = min((0:stepLength:Sim.SimulationTime));
        ymax = max(0:stepLength:Sim.SimulationTime);
        axis([ymin ymax xmin xmax]);
    end    
    
    
    %Azimuth angles       
    figure('name','Azimuth setpoint angles: qpOASES');
    hold on;
    grid on;
    for i=1:nt
        s = cell(1, size(nt,1));
        subplot(3,1,i)
        plot((0:stepLength:Sim.SimulationTime), (180/pi).*Alpha_qpOASES_plot(:,i),'k', ...
            (0:stepLength:Sim.SimulationTime), (180/pi).*(alpha_max(i).*ones(1,length(0:stepLength:Sim.SimulationTime))), ...
            (0:stepLength:Sim.SimulationTime), (180/pi).*(alpha_min(i).*ones(1,length(0:stepLength:Sim.SimulationTime))));
        set(0,'DefaultAxesColorOrder',[1 0 0],...
            'DefaultAxesLineStyleOrder','-|--|:|-.', 'defaultlinelinewidth',2)
        xlabel('Time [s]');
        ylabel('Azimuth angle in [DEG]');
        legend('Alpha_d', 'Alpha_{max}', 'Alpha_{min}');
        xmin = (180/pi)*alpha_max(i)-1;
        xmax = (180/pi)*alpha_min(i)+1;
        ymin = min(0:stepLength:Sim.SimulationTime);
        ymax = max(0:stepLength:Sim.SimulationTime);
        %axis([time(1) time(length(time)) xmin xmax]);
    end 

    %diffqpOASESandTauc
    figure('name','diffqpOASESandTauc');
    grid on;
    hold on;
    plot((0:stepLength:Sim.SimulationTime), diffqpOASESandTauc(:,1,:), 'k');
    plot((0:stepLength:Sim.SimulationTime), diffqpOASESandTauc(:,2,:), 'b');
    plot((0:stepLength:Sim.SimulationTime), diffqpOASESandTauc(:,3,:), 'r');
    xlabel('Time [s]');
    ylabel('diffqpOASESandTauc');
    legend('X','Y','N');
    title('Error Between qpOASES and tau_c');
    hold off;

    %diffqpOASESandTaucWithS
    figure('name','diffqpOASESandTaucWithS');
    grid on;
    hold on;
    plot((0:stepLength:Sim.SimulationTime), diffqpOASESandTaucWithS(:,1,:), 'k');
    plot((0:stepLength:Sim.SimulationTime), diffqpOASESandTaucWithS(:,2,:), 'b');
    plot((0:stepLength:Sim.SimulationTime), diffqpOASESandTaucWithS(:,3,:), 'r');
    xlabel('Time [s]');
    ylabel('diffqpOASESandTaucWithS');
    legend('X','Y','N');
    title('Error Between qpOASES and tau_c including s: diffqpOASESandTaucWithS');
    hold off;

    %diffqpOASESandTaucWithSLinearized
    figure('name','diffqpOASESandTaucWithSLinearized');
    grid on;
    hold on;
    plot((0:stepLength:Sim.SimulationTime), diffqpOASESandTaucWithSLinearized(:,1,:), 'k');
    plot((0:stepLength:Sim.SimulationTime), diffqpOASESandTaucWithSLinearized(:,2,:), 'b');
    plot((0:stepLength:Sim.SimulationTime), diffqpOASESandTaucWithSLinearized(:,3,:), 'r');
    xlabel('Time [s]');
    ylabel('diffqpOASESandTaucWithSLinearized');
    legend('X','Y','N');
    title('Error Between qpOASES and tau_c including s Linearized function: diffqpOASESandTaucWithSLinearized');
    hold off;

    %diffqpOASESCostFunction
    figure('name','diffqpOASESCostFunction');
    grid on;
    hold on;
    plot((0:stepLength:Sim.SimulationTime), diffqpOASESCostFunction, 'k');
    plot((0:stepLength:Sim.SimulationTime), diffqpOASESCostFunction, 'b');
    plot((0:stepLength:Sim.SimulationTime), diffqpOASESCostFunction, 'r');
    xlabel('Time [s]');
    ylabel('diffqpOASESCostFunction');
    legend('Cost Function');
    title('Difference between calculated cost function and output from qpOASES algorithm: diffqpOASESCostFunction');
    hold off;


