%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
%
% Save_struct.m
%
% Project:	"Marine Cybernetics Simulator: MCSim"
%
% Abstract:	Store simulation data from Simulink in one structure:
%			- Desired variables from the simulation
%			- The Par-structure with all simulation parameters
%			- The Sim-structure with all simulation settings
% 
%			To be run as callback from Simulink after a simulation
%
% Inputs:	-
%
% Outputs:	All simulation data stored in structure Saved
%	
% Calls:	-
%		
% Author:	yvind Smogeli, Summer 2003
%
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 

% Clear old Saved structure
clear Saved

% Simulation data to be stored
% Add data following the same convention

% Vessel data
Saved.t 			= time_out;
Saved.Eta_LF 		= Eta_LF_out;
Saved.Eta_WF	 	= Eta_WF_out;
Saved.Eta 			= Eta_LF_out + Eta_WF_out;
Saved.Nu_LF 		= Nu_LF_out;
Saved.Nu_WF 		= Nu_WF_out;
Saved.Nu 			= Nu_LF_out + Nu_WF_out;
Saved.Nu_d_LF 		= Nu_d_LF_out;
Saved.Nu_d_WF	 	= Nu_d_WF_out;
Saved.Nu_d 			= Nu_d_LF_out + Nu_d_WF_out;
Saved.F_wind 		= F_wind_out;
Saved.F_current 	= F_current_out;
Saved.F_wavedrift 	= F_wavedrift_out;
Saved.Tau_T			= Tau_T_out;

% Control data
Saved.Tau_c			= Tau_c_out;
Saved.Nu_d_des		= Nu_d_des_out;
Saved.Nu_des		= Nu_des_out;
Saved.Eta_des		= Eta_des_out;
Saved.Nu_d_hat		= Nu_d_hat_out;
Saved.Nu_hat		= Nu_hat_out;
Saved.Eta_hat		= Eta_hat_out;

% Sensor data
Saved.Wind_meas		= Wind_meas_out;
Saved.Nu_d_meas		= Nu_d_meas_out;
Saved.Nu_meas		= Nu_meas_out;
Saved.Eta_meas		= Eta_meas_out;


% Thruster data, all data saved in one structure
% 1 T_nom
% 2 Q_nom
% 3	T_p_ax
% 4	Q_p_ax
% 5 RPM_p
% 6 Beta_vent
% 7 Beta_cc
% 8 V_a(1)
% 9 V_a(2)
% 10 V_a(3)
% 11 h
% 12 h2
% 13 Q_m

for i = 1:Sim.nthrusters
	
	n = 1;
	% Thruster dynamics data
	eval(['Saved.Prop{i}.T_p_nom = Thruster_out_', num2str(i),'(:,' num2str(n),');']); n = n + 1;	% 1
	eval(['Saved.Prop{i}.Q_p_nom = Thruster_out_', num2str(i),'(:,' num2str(n),');']); n = n + 1;	% 2
	eval(['Saved.Prop{i}.T_p_ax = Thruster_out_', num2str(i),'(:,' num2str(n),');']); n = n + 1;	% 3 
	eval(['Saved.Prop{i}.Q_p_ax = Thruster_out_', num2str(i),'(:,' num2str(n),');']); n = n + 1;	% 4
	eval(['Saved.Prop{i}.RPM_p = Thruster_out_', num2str(i),'(:,' num2str(n),');']); n = n + 1;		% 5
	eval(['Saved.Prop{i}.Beta_vent = Thruster_out_', num2str(i),'(:,' num2str(n),');']); n = n + 1;	% 6
	eval(['Saved.Prop{i}.Beta_cc = Thruster_out_', num2str(i),'(:,' num2str(n),');']); n = n + 1;	% 7
	eval(['Saved.Prop{i}.Va = Thruster_out_', num2str(i),'(:,' num2str(n),':', num2str(n + 2),');']); n = n + 3; % 8-10
	eval(['Saved.Prop{i}.h = Thruster_out_', num2str(i),'(:,' num2str(n),');']); n = n + 1;			% 11
	eval(['Saved.Prop{i}.h2 = Thruster_out_', num2str(i),'(:,' num2str(n),');']); n = n + 1;		% 12
	eval(['Saved.Prop{i}.Q_motor = Thruster_out_', num2str(i),'(:,' num2str(n),');']); n = n + 1;	% 13
	
	% Control data
	eval(['Saved.Prop{i}.Q_ctr = Thruster_out_', num2str(i),'(:,' num2str(n),');']); n = n + 1;		% 14 Commanded torque from controller
	eval(['Saved.Prop{i}.T_des = Thruster_out_', num2str(i),'(:,' num2str(n),');']); n = n + 1;		% 15 Desired thrust from thrust allocation
	
end