%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
%
% Vessel_results.m
%
% Project:	"Marine Cybernetics Simulator: MCSim"
%
% Abstract:	Present MCSim simulation data from "Saved" structure in workspace.
%			"Saved" structure can be from the last simulation or loaded from
%			a stored mat-file into workspace.
%
% Inputs:	-
%
% Outputs:	-
%	
% Calls:	-
%		
% Author:	yvind Smogeli, Summer 2003
%
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 

% Change window size for big plots
window_size = [100   100   500   800];

% Position for NED position and velocity/direction plots
window_pos_NED = [680 550 560 400];	%[360 514 560 420] Matlab default
window_pos_vel = [680 50 560 400];	%[360 514 560 420] Matlab default

disp('Displaying data from "Saved" structure in Workspace')
		
nsteps = length(Saved.t);

% Total speed
vtot = sqrt(Saved.Nu(:,1).^2 + Saved.Nu(:,2).^2);

% Direction
for ii = 2:nsteps
	Saved.Etashift(ii-1,:) = Saved.Eta(ii,:);
end

Saved.Etashift(nsteps,:) = Saved.Etashift(nsteps-1,:);
deltaEta = Saved.Etashift-Saved.Eta;
direction = atan2(deltaEta(:,2),deltaEta(:,1))*180/pi;

% % Result checking
% for k = 1:6
%     
%     Eta_WF_mean(k) = mean(Saved.Eta_WF(:,k));
%     Nu_WF_mean(k) = mean(Saved.Nu_WF(:,k));
%     Nu_d_WF_mean(k) = mean(Saved.Nu_d_WF(:,k));
%     
% end
% 
% disp(' ')
% disp('Mean values of WF motion:')
% disp(['Eta_WF  : ', num2str(Eta_WF_mean)])
% disp(['Nu_WF   : ', num2str(Nu_WF_mean)])
% disp(['Nu_d_WF : ', num2str(Nu_d_WF_mean)])


etafig = figure;
subplot(6,1,1)
plot(Saved.t, Saved.Eta(:,1), 'k-', Saved.t, Saved.Eta_WF(:,1), 'b-', Saved.t, Saved.Eta_LF(:,1), 'r-')
title('\eta [m, deg] (black = LF + WF, blue = WF, red = LF)')
ylabel('x')
subplot(6,1,2)
plot(Saved.t, Saved.Eta(:,2), 'k-', Saved.t, Saved.Eta_WF(:,2), 'b-', Saved.t, Saved.Eta_LF(:,2), 'r-')
ylabel('y')
subplot(6,1,3)
plot(Saved.t, Saved.Eta(:,3), 'k-', Saved.t, Saved.Eta_WF(:,3), 'b-', Saved.t, Saved.Eta_LF(:,3), 'r-')
ylabel('z')
subplot(6,1,4)
plot(Saved.t, Saved.Eta(:,4)*180/pi, 'k-', Saved.t, Saved.Eta_WF(:,4)*180/pi, 'b-', Saved.t, Saved.Eta_LF(:,4)*180/pi, 'r-')
ylabel('\phi')
subplot(6,1,5)
plot(Saved.t, Saved.Eta(:,5)*180/pi, 'k-', Saved.t, Saved.Eta_WF(:,5)*180/pi, 'b-', Saved.t, Saved.Eta_LF(:,5)*180/pi, 'r-')
ylabel('\theta')
subplot(6,1,6)
plot(Saved.t, Saved.Eta(:,6)*180/pi, 'k-', Saved.t, Saved.Eta_WF(:,6)*180/pi, 'b-', Saved.t, Saved.Eta_LF(:,6)*180/pi, 'r-')
ylabel('\psi')
xlabel('t')
set(gcf,'Position',window_size);  %Enlarge window



figure
subplot(6,1,1)
plot(Saved.t, Saved.Nu(:,1), 'k-', Saved.t, Saved.Nu_WF(:,1), 'b-', Saved.t, Saved.Nu_LF(:,1), 'r-')
title('\nu [m/s, rad/s] (black = LF + WF, blue = WF, red = LF)')
ylabel('u')
subplot(6,1,2)
plot(Saved.t, Saved.Nu(:,2), 'k-', Saved.t, Saved.Nu_WF(:,2), 'b-', Saved.t, Saved.Nu_LF(:,2), 'r-')
ylabel('v')
subplot(6,1,3)
plot(Saved.t, Saved.Nu(:,3), 'k-', Saved.t, Saved.Nu_WF(:,3), 'b-', Saved.t, Saved.Nu_LF(:,3), 'r-')
ylabel('w')
subplot(6,1,4)
plot(Saved.t, Saved.Nu(:,4)*180/pi, 'k-', Saved.t, Saved.Nu_WF(:,4)*180/pi, 'b-', Saved.t, Saved.Nu_LF(:,4)*180/pi, 'r-')
ylabel('p')
subplot(6,1,5)
plot(Saved.t, Saved.Nu(:,5)*180/pi, 'k-', Saved.t, Saved.Nu_WF(:,5)*180/pi, 'b-', Saved.t, Saved.Nu_LF(:,5)*180/pi, 'r-')
ylabel('q')
subplot(6,1,6)
plot(Saved.t, Saved.Nu(:,6)*180/pi, 'k-', Saved.t, Saved.Nu_WF(:,6)*180/pi, 'b-', Saved.t, Saved.Nu_LF(:,6)*180/pi, 'r-')
ylabel('r')
xlabel('t')
set(gcf,'Position',window_size);  %Enlarge window


figure
subplot(6,1,1)
plot(Saved.t, Saved.Nu_d(:,1), 'k-', Saved.t, Saved.Nu_d_WF(:,1), 'b-', Saved.t, Saved.Nu_d_LF(:,1), 'r-')
title('\nu_d [m/s^2, rad/s^2] (black = LF + WF, blue = WF, red = LF)')
ylabel('u_d')
subplot(6,1,2)
plot(Saved.t, Saved.Nu_d(:,2), 'k-', Saved.t, Saved.Nu_d_WF(:,2), 'b-', Saved.t, Saved.Nu_d_LF(:,2), 'r-')
ylabel('v_d')
subplot(6,1,3)
plot(Saved.t, Saved.Nu_d(:,3), 'k-', Saved.t, Saved.Nu_d_WF(:,3), 'b-', Saved.t, Saved.Nu_d_LF(:,3), 'r-')
ylabel('w_d')
subplot(6,1,4)
plot(Saved.t, Saved.Nu_d(:,4)*180/pi, 'k-', Saved.t, Saved.Nu_d_WF(:,4)*180/pi, 'b-', Saved.t, Saved.Nu_d_LF(:,4)*180/pi, 'r-')
ylabel('p_d')
subplot(6,1,5)
plot(Saved.t, Saved.Nu_d(:,5)*180/pi, 'k-', Saved.t, Saved.Nu_d_WF(:,5)*180/pi, 'b-', Saved.t, Saved.Nu_d_LF(:,5)*180/pi, 'r-')
ylabel('q_d')
subplot(6,1,6)
plot(Saved.t, Saved.Nu_d(:,6)*180/pi, 'k-', Saved.t, Saved.Nu_d_WF(:,6)*180/pi, 'b-', Saved.t, Saved.Nu_d_LF(:,6)*180/pi, 'r-')
ylabel('r_d')
xlabel('t')
set(gcf,'Position',window_size);  %Enlarge window




figure
subplot(2,1,1)
plot(Saved.t,vtot)
title('V_{tot} [m/s]')
subplot(2,1,2)
plot(Saved.t,direction)
title('direction [deg]')
set(gcf,'Position',window_pos_vel);  

figure
plot(Saved.Eta_WF(:,2)+Saved.Eta_LF(:,2),Saved.Eta_WF(:,1)+Saved.Eta_LF(:,1),'b')
hold on
plot(Saved.Eta_LF(:,2),Saved.Eta_LF(:,1),'r')
title('Position in NED (blue = LF+WF, red = LF)')
xlabel('y')
ylabel('x')
set(gcf,'Position',window_pos_NED);  


figure
subplot(6,1,1)
plot(Saved.t, Saved.Tau_T(:,1))
title('Thruster force [N, Nm]')
ylabel('F1')
subplot(6,1,2)
plot(Saved.t, Saved.Tau_T(:,2))
ylabel('F2')
subplot(6,1,3)
plot(Saved.t, Saved.Tau_T(:,3))
ylabel('F3')
subplot(6,1,4)
plot(Saved.t, Saved.Tau_T(:,4))
ylabel('F4')
subplot(6,1,5)
plot(Saved.t, Saved.Tau_T(:,5))
ylabel('F5')
subplot(6,1,6)
plot(Saved.t, Saved.Tau_T(:,6))
ylabel('F6')
xlabel('t')
set(gcf,'Position',window_size);  %Enlarge window


if Sim.LF_model == 1 & Sim.Force_plots == 1
	
	
	figure
	subplot(6,1,1)
	plot(Saved.t, Saved.F_current(:,1))
	title('Current force [N]')
	ylabel('F1')
	subplot(6,1,2)
	plot(Saved.t, Saved.F_current(:,2))
	ylabel('F2')
	subplot(6,1,3)
	plot(Saved.t, Saved.F_current(:,3))
	ylabel('F3')
	subplot(6,1,4)
	plot(Saved.t, Saved.F_current(:,4))
	ylabel('F4')
	subplot(6,1,5)
	plot(Saved.t, Saved.F_current(:,5))
	ylabel('F5')
	subplot(6,1,6)
	plot(Saved.t, Saved.F_current(:,6))
	ylabel('F6')
	xlabel('t')
	set(gcf,'Position',window_size);  %Enlarge window

	
	figure
	subplot(6,1,1)
	plot(Saved.t, Saved.F_wavedrift(:,1))
	title('Wavedrift force [N]')
	ylabel('F1')
	subplot(6,1,2)
	plot(Saved.t, Saved.F_wavedrift(:,2))
	ylabel('F2')
	subplot(6,1,3)
	plot(Saved.t, Saved.F_wavedrift(:,3))
	ylabel('F3')
	subplot(6,1,4)
	plot(Saved.t, Saved.F_wavedrift(:,4))
	ylabel('F4')
	subplot(6,1,5)
	plot(Saved.t, Saved.F_wavedrift(:,5))
	ylabel('F5')
	subplot(6,1,6)
	plot(Saved.t, Saved.F_wavedrift(:,6))
	ylabel('F6')
	xlabel('t')
	set(gcf,'Position',window_size);  %Enlarge window

	
	figure
	subplot(6,1,1)
	plot(Saved.t, Saved.F_wind(:,1))
	title('Wind force [N]')
	ylabel('F1')
	subplot(6,1,2)
	plot(Saved.t, Saved.F_wind(:,2))
	ylabel('F2')
	subplot(6,1,3)
	plot(Saved.t, Saved.F_wind(:,3))
	ylabel('F3')
	subplot(6,1,4)
	plot(Saved.t, Saved.F_wind(:,4))
	ylabel('F4')
	subplot(6,1,5)
	plot(Saved.t, Saved.F_wind(:,5))
	ylabel('F5')
	subplot(6,1,6)
	plot(Saved.t, Saved.F_wind(:,6))
	ylabel('F6')
	xlabel('t')
	set(gcf,'Position',window_size);  %Enlarge window
	
end

% Show the NED position figure
figure(etafig)


