% Test wave realization
close all

xdist = 1000;
ydist = 1000;

xpoints = 100;
ypoints = 100;

t = 0;

az = -50;
el = 70;

%----------------------------------------------------------------

g = 9.81;

Zeta = zeros(xpoints+1, ypoints+1);
Z_temp = Zeta;

dx = xdist/xpoints;
dy = ydist/ypoints;

xvec = 0:dx:xdist;
yvec = 0:dy:ydist;

nwaves = length(Par.Wave.Zeta_a);

hh = waitbar(0,'Running wave realization, please wait....');

for n = 1:nwaves
	
	% Particulars for one harmonic wave 
	zeta_a = Par.Wave.Zeta_a(n);
	psi_w = Par.Wave.Psi_w(n);
	omega_w = Par.Wave.Omega(n);
	phase_w = Par.Wave.Phase(n);
		
	xc = 0;
	
	for x = xvec
		
		xc = xc + 1;
		
		yc = 0;
		
		for y = yvec
			
			yc = yc + 1;
			
			%x_rel = rotate_yaw_T(psi_w)*[x, y, 0]'; %Old routine, changed to gnc toolbox
			x_rel = Rzyx(0,0,-psi_w)*[x, y, 0]'; % Same as transposed rotation matrix in yaw
			x_rel = x_rel(1);
			
			% Wave number k from deepwater dispersion relation
			k = omega_w^2/g;
			
			% Phase due to x_rel, negative because it gives lag:
			phase_pos = -x_rel*k; % [rad] (= -x_rel/lambda)
			
			% Wave elevation
			Z_temp(xc,yc) = zeta_a*sin(omega_w*t + phase_w + phase_pos);
			
		end %y
			
	end %x
	
	waitbar(n/nwaves, hh);

	Zeta = Zeta + Z_temp;
		
end % waves

close(hh)

% Test if hs is correct
hs_sim=4*sqrt(mean(mean(Zeta.^2)));

disp(['hs input: ', num2str(Par.Wave.hs)])
disp(['hs sim:   ', num2str(hs_sim)])

figure
mesh(yvec,xvec,Zeta)
xlabel('y')
ylabel('x')
title('Wave realization')
zlabel('z')
view(az,el)
